@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,23 +22,23 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.adv_search.php 1.10 03/10/27 18:47:52-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.category.php");
-include_once(APP_INC_PATH . "class.priority.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.release.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.filter.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.user.php");
+// @(#) $Id: adv_search.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.category.php");
+require_once(APP_INC_PATH . "class.priority.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.release.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.filter.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.user.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("adv_search.tpl.html");
@@ -47,7 +47,7 @@ Auth::checkAuthentication(APP_COOKIE);
 
 // customers should not be able to see this page
 $role_id = Auth::getCurrentRole();
-if ($role_id < User::getRoleID('Standard User')) {
+if ($role_id == User::getRoleID('Customer')) {
     Auth::redirect(APP_RELATIVE_URL . "list.php");
 }
 
@@ -83,15 +83,14 @@ $tpl->assign(array(
     "reporters"     => Project::getReporters($prj_id)
 ));
 
-if (!empty($HTTP_GET_VARS["custom_id"])) {
+if (!empty($_GET["custom_id"])) {
     $check_perm = true;
-    if (Filter::isGlobal($HTTP_GET_VARS["custom_id"])) {
+    if (Filter::isGlobal($_GET["custom_id"])) {
         if ($role_id >= User::getRoleID('Manager')) {
             $check_perm = false;
         }
     }
-    $tpl->assign("options", Filter::getDetails($HTTP_GET_VARS["custom_id"], $check_perm));
+    $tpl->assign("options", Filter::getDetails($_GET["custom_id"], $check_perm));
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
