@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,15 +25,15 @@
 // | Authors: Bryan Alsdorf <bryan@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.authorized_replier.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: authorized_replier.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.authorized_replier.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("authorized_replier.tpl.html");
@@ -41,14 +41,14 @@ $tpl->setTemplate("authorized_replier.tpl.html");
 Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 
 $prj_id = Auth::getCurrentProject();
-$issue_id = @$HTTP_POST_VARS["issue_id"] ? $HTTP_POST_VARS["issue_id"] : $HTTP_GET_VARS["iss_id"];
+$issue_id = @$_POST["issue_id"] ? $_POST["issue_id"] : $_GET["iss_id"];
 $tpl->assign("issue_id", $issue_id);
 
-if (@$HTTP_POST_VARS["cat"] == "insert") {
-    $res = Authorized_Replier::manualInsert($issue_id, $HTTP_POST_VARS['email']);
+if (@$_POST["cat"] == "insert") {
+    $res = Authorized_Replier::manualInsert($issue_id, $_POST['email']);
     $tpl->assign("insert_result", $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "delete") {
-    $res = Authorized_Replier::removeRepliers($HTTP_POST_VARS["items"]);
+} elseif (@$_POST["cat"] == "delete") {
+    $res = Authorized_Replier::removeRepliers($_POST["items"]);
     $tpl->assign("delete_result", $res);
 }
 
@@ -59,4 +59,3 @@ $t = Project::getAddressBook($prj_id, $issue_id);
 $tpl->assign("assoc_users", $t);
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
