@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,21 +22,21 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.close.php 1.8 04/01/09 05:04:09-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.resolution.php");
-include_once(APP_INC_PATH . "class.time_tracking.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: close.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.resolution.php");
+require_once(APP_INC_PATH . "class.time_tracking.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("close.tpl.html");
@@ -44,20 +44,26 @@ $tpl->setTemplate("close.tpl.html");
 Auth::checkAuthentication(APP_COOKIE);
 
 $prj_id = Auth::getCurrentProject();
-$issue_id = @$HTTP_POST_VARS["issue_id"] ? $HTTP_POST_VARS["issue_id"] : $HTTP_GET_VARS["id"];
+$issue_id = @$_POST["issue_id"] ? $_POST["issue_id"] : @$_GET["id"];
 $tpl->assign("extra_title", "Close Issue #$issue_id");
 
+if (!Issue::exists($issue_id, false)) {
+    $tpl->assign("no_issue", true);
+    $tpl->displayTemplate();
+    exit;
+}
+
 $notification_list = Notification::getSubscribers($issue_id, 'closed');
 $tpl->assign("notification_list_all", $notification_list['all']);
 
-$notification_list_internal = Notification::getSubscribers($issue_id, 'closed', User::getRoleID("standard User"));
+$notification_list_internal = Notification::getSubscribers($issue_id, 'closed', User::getRoleID("Standard User"));
 $tpl->assign("notification_list_internal", $notification_list_internal['all']);
 
-if (@$HTTP_POST_VARS["cat"] == "close") {
-    $res = Issue::close(Auth::getUserID(), $HTTP_POST_VARS["issue_id"], $HTTP_POST_VARS["send_notification"], $HTTP_POST_VARS["resolution"], $HTTP_POST_VARS["status"], $HTTP_POST_VARS["reason"], @$_REQUEST['notification_list']);
+if (@$_POST["cat"] == "close") {
+    $res = Issue::close(Auth::getUserID(), $_POST["issue_id"], $_POST["send_notification"], $_POST["resolution"], $_POST["status"], $_POST["reason"], @$_REQUEST['notification_list']);
 
-    if (!empty($HTTP_POST_VARS['time_spent'])) {
-        $HTTP_POST_VARS['summary'] = 'Time entry inserted when closing issue.';
+    if (!empty($_POST['time_spent'])) {
+        $_POST['summary'] = 'Time entry inserted when closing issue.';
         Time_Tracking::insertEntry();
     }
 
@@ -80,5 +86,8 @@ if ((Customer::hasCustomerIntegration($prj_id)) && (Customer::hasPerIncidentCont
     ));
 }
 
+$usr_id = Auth::getUserID();
+$user_prefs = Prefs::get($usr_id);
+$tpl->assign("current_user_prefs", $user_prefs);
+
 $tpl->displayTemplate();
-?>
\ No newline at end of file
