@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,28 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.csv.php 1.4 03/01/16 01:47:31-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: csv.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . '/init.php');
+require_once(APP_INC_PATH . 'class.auth.php');
+require_once(APP_INC_PATH . 'db_access.php');
 
 Auth::checkAuthentication(APP_COOKIE);
 
-$csv = base64_decode($HTTP_POST_VARS["csv_data"]);
+$csv = base64_decode($_POST['csv_data']);
+
+header('Expires: Mon, 26 Jul 1997 05:00:00 GMT'); // Date in the past
+header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT'); // always modified
+header('Pragma: no-cache');
+header('Cache-Control: must-revalidate, post-check=0,pre-check=0');
+
+header('Content-Type: application/vnd.ms-excel');
+header('Content-Disposition: attachment; filename='. uniqid('') . '.xls');
+header('Content-Length: ' . strlen($csv));
 
-header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
-header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // always modified
-header("Pragma: no-cache");
-header("Content-Type: application/vnd.ms-excel");
-header("Content-Disposition: attachment; filename=".uniqid('').'.xls');
-header("Expires: 0");
-header("Cache-Control: must-revalidate, post-check=0,pre-check=0");
-header("Content-Type: application/vnd.ms-excel");
-header("Content-Disposition: \"inline\"");
-header("Content-Length: " . strlen($csv));
 echo $csv;
-?>
\ No newline at end of file
