@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,15 +22,15 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.download.php 1.14 04/01/26 20:37:04-06:00 joao@kickass. $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.attachment.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: download.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.attachment.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 Auth::checkAuthentication(APP_COOKIE);
 
@@ -42,8 +42,8 @@ if (stristr(APP_BASE_URL, 'https:')) {
 // fix for IE6 (KB812935)
 header('Cache-Control: must-revalidate');
 
-if ($HTTP_GET_VARS['cat'] == 'attachment') {
-    $file = Attachment::getDetails($HTTP_GET_VARS["id"]);
+if ($_GET['cat'] == 'attachment') {
+    $file = Attachment::getDetails($_GET["id"]);
     if (!empty($file)) {
         if (!Issue::canAccess($file['iat_iss_id'], Auth::getUserID())) {
             $tpl = new Template_API();
@@ -54,4 +54,3 @@ if ($HTTP_GET_VARS['cat'] == 'attachment') {
         Attachment::outputDownload($file['iaf_file'], $file["iaf_filename"], $file['iaf_filesize'], $file['iaf_filetype']);
     }
 }
-?>
