@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,17 +22,17 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.faq.php");
-include_once(APP_INC_PATH . "class.customer.php");
+// @(#) $Id: faq.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.faq.php");
+require_once(APP_INC_PATH . "class.customer.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("faq.tpl.html");
@@ -61,8 +61,8 @@ if (!Customer::hasCustomerIntegration($prj_id)) {
 }
 $tpl->assign("faqs", FAQ::getListBySupportLevel($support_level_id));
 
-if (!empty($HTTP_GET_VARS["id"])) {
-    $t = FAQ::getDetails($HTTP_GET_VARS['id']);
+if (!empty($_GET["id"])) {
+    $t = FAQ::getDetails($_GET['id']);
     // check if this customer should have access to this FAQ entry or not
     if (($support_level_id != -1) && (!in_array($support_level_id, $t['support_levels']))) {
         $tpl->assign('faq', -1);
@@ -73,4 +73,3 @@ if (!empty($HTTP_GET_VARS["id"])) {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
