@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,28 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-//
 
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.history.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.workflow.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.workflow.php");
 
 /**
  * Class designed to handle all business logic related to attachments being
  * uploaded to issues in the application.
  *
- * @author  Joo Prado Maia <jpm@mysql.com>
- * @version $Revision: 1.28 $
+ * @author  João Prado Maia <jpm@mysql.com>
  */
 class Attachment
 {
@@ -103,7 +101,8 @@ class Attachment
             'png',
             'bmp',
             'html',
-            'htm'
+            'htm',
+            'xml',
         );
     }
 
@@ -171,8 +170,11 @@ class Attachment
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_attachment_file
                  WHERE
                     iaf_id=$iaf_id AND
-                    iat_id=iaf_iat_id AND
+                    iat_id=iaf_iat_id";
+        if (Auth::getCurrentRole() < User::getRoleID("Manager")) {
+            $stmt .= " AND
                     iat_usr_id=$usr_id";
+        }
         $res = $GLOBALS["db_api"]->dbh->getOne($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -271,6 +273,7 @@ class Attachment
     /**
      * Method used to remove attachments from the database.
      *
+     * @param   integer $iat_id attachment_id.
      * @access  public
      * @return  integer Numeric code used to check for any errors
      */
@@ -283,8 +286,11 @@ class Attachment
                  FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_attachment
                  WHERE
-                    iat_id=$iat_id AND
+                    iat_id=$iat_id";
+        if (Auth::getCurrentRole() < User::getRoleID("Manager")) {
+            $stmt .= " AND
                     iat_usr_id=$usr_id";
+        }
         $res = $GLOBALS["db_api"]->dbh->getOne($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -293,20 +299,24 @@ class Attachment
             if (empty($res)) {
                 return -2;
             } else {
+                $issue_id = $res;
                 $files = Attachment::getFileList($iat_id);
                 $stmt = "DELETE FROM
                             " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_attachment
                          WHERE
                             iat_id=$iat_id AND
-                            iat_iss_id=$res AND
-                            iat_usr_id=$usr_id";
-                $GLOBALS["db_api"]->dbh->query($stmt);
+                            iat_iss_id=$issue_id";
+                $res = $GLOBALS["db_api"]->dbh->query($stmt);
+                if (PEAR::isError($res)) {
+                    Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+                    return -1;
+                }
                 for ($i = 0; $i < count($files); $i++) {
                     Attachment::removeFile($files[$i]['iaf_id']);
                 }
-                Issue::markAsUpdated($res);
+                Issue::markAsUpdated($issue_id);
                 // need to save a history entry for this
-                History::add($res, $usr_id, History::getTypeID('attachment_removed'), 'Attachment removed by ' . User::getFullName($usr_id));
+                History::add($issue_id, $usr_id, History::getTypeID('attachment_removed'), 'Attachment removed by ' . User::getFullName($usr_id));
                 return 1;
             }
         }
@@ -328,7 +338,11 @@ class Attachment
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_attachment_file
                  WHERE
                     iaf_id=" . $iaf_id;
-        $GLOBALS["db_api"]->dbh->query($stmt);
+        $res = $GLOBALS["db_api"]->dbh->query($stmt);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return -1;
+        }
     }
 
 
@@ -428,21 +442,19 @@ class Attachment
      */
     function attach($usr_id, $status = 'public')
     {
-        global $HTTP_POST_VARS, $HTTP_POST_FILES;
-
         $files = array();
-        for ($i = 0; $i < count($HTTP_POST_FILES["attachment"]["name"]); $i++) {
-            $filename = @$HTTP_POST_FILES["attachment"]["name"][$i];
+        for ($i = 0; $i < count($_FILES["attachment"]["name"]); $i++) {
+            $filename = @$_FILES["attachment"]["name"][$i];
             if (empty($filename)) {
                 continue;
             }
-            $blob = Misc::getFileContents($HTTP_POST_FILES["attachment"]["tmp_name"][$i]);
+            $blob = Misc::getFileContents($_FILES["attachment"]["tmp_name"][$i]);
             if (empty($blob)) {
                 return -1;
             }
             $files[] = array(
                 "filename"  =>  $filename,
-                "type"      =>  $HTTP_POST_FILES['attachment']['type'][$i],
+                "type"      =>  $_FILES['attachment']['type'][$i],
                 "blob"      =>  $blob
             );
         }
@@ -454,26 +466,26 @@ class Attachment
         } else {
             $internal_only = false;
         }
-        $attachment_id = Attachment::add($HTTP_POST_VARS["issue_id"], $usr_id, @$HTTP_POST_VARS["file_description"], $internal_only);
+        $attachment_id = Attachment::add($_POST["issue_id"], $usr_id, @$_POST["file_description"], $internal_only);
         foreach ($files as $file) {
-            Attachment::addFile($attachment_id, $HTTP_POST_VARS["issue_id"], $file["filename"], $file["type"], $file["blob"]);
+            Attachment::addFile($attachment_id, $file["filename"], $file["type"], $file["blob"]);
         }
 
-        Issue::markAsUpdated($HTTP_POST_VARS["issue_id"], "file uploaded");
+        Issue::markAsUpdated($_POST["issue_id"], "file uploaded");
         // need to save a history entry for this
-        History::add($HTTP_POST_VARS["issue_id"], $usr_id, History::getTypeID('attachment_added'), 'Attachment uploaded by ' . User::getFullName($usr_id));
+        History::add($_POST["issue_id"], $usr_id, History::getTypeID('attachment_added'), 'Attachment uploaded by ' . User::getFullName($usr_id));
 
         // if there is customer integration, mark last customer action
-        if ((Customer::hasCustomerIntegration(Issue::getProjectID($HTTP_POST_VARS["issue_id"]))) && (User::getRoleByUser($usr_id, Issue::getProjectID($HTTP_POST_VARS["issue_id"])) == User::getRoleID('Customer'))) {
-            Issue::recordLastCustomerAction($HTTP_POST_VARS["issue_id"]);
+        if ((Customer::hasCustomerIntegration(Issue::getProjectID($_POST["issue_id"]))) && (User::getRoleByUser($usr_id, Issue::getProjectID($_POST["issue_id"])) == User::getRoleID('Customer'))) {
+            Issue::recordLastCustomerAction($_POST["issue_id"]);
         }
 
-        Workflow::handleAttachment(Issue::getProjectID($HTTP_POST_VARS["issue_id"]), $HTTP_POST_VARS["issue_id"], $usr_id);
+        Workflow::handleAttachment(Issue::getProjectID($_POST["issue_id"]), $_POST["issue_id"], $usr_id);
 
         // send notifications for the issue being updated
         // XXX: eventually need to restrict the list of people who receive a notification about this in a better fashion
         if ($status == 'public') {
-            Notification::notify($HTTP_POST_VARS["issue_id"], 'files', $attachment_id);
+            Notification::notify($_POST["issue_id"], 'files', $attachment_id);
         }
         return 1;
     }
@@ -484,11 +496,10 @@ class Attachment
      *
      * @access  public
      * @param   integer $attachment_id The attachment ID
-     * @param   integer $issue_id The issue ID
      * @param   string $filename The filename to be added
      * @return  boolean
      */
-    function addFile($attachment_id, $issue_id, $filename, $filetype, &$blob)
+    function addFile($attachment_id, $filename, $filetype, &$blob)
     {
         $filesize = strlen($blob);
         $stmt = "INSERT INTO
@@ -504,7 +515,7 @@ class Attachment
                     '" . Misc::escapeString($filename) . "',
                     '" . $filesize . "',
                     '" . Misc::escapeString($filetype) . "',
-                    '" . addslashes($blob) . "'
+                    '" . Misc::escapeString($blob) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -530,8 +541,6 @@ class Attachment
      */
     function add($issue_id, $usr_id, $description, $internal_only = FALSE, $unknown_user = FALSE, $associated_note_id = FALSE)
     {
-        global $HTTP_POST_VARS;
-
         if ($internal_only) {
             $attachment_status = 'internal';
         } else {
@@ -559,12 +568,12 @@ class Attachment
                     '" . Misc::escapeString($description) . "',
                     '" . Misc::escapeString($attachment_status) . "'";
         if ($unknown_user != false) {
-            $stmt .= ", '$unknown_user'";
+            $stmt .= ", '" . Misc::escapeString($unknown_user) . "'";
         }
         if ($associated_note_id != false) {
-            $stmt .= ", $associated_note_id ";
+            $stmt .= ", " . Misc::escapeInteger($associated_note_id);
         }
-        $stmt .= ")";
+        $stmt .= " )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -578,14 +587,18 @@ class Attachment
     /**
      * Method used to replace unsafe characters by safe characters.
      *
+     * Side-effects: if $name is not in ISO8859-1 encoding, not very logical
+     * replacements are done. Eventually the non-ASCII characters are stripped.
+     *
      * @access  public
-     * @param   string $name The name of the file to be checked
+     * @param   string $name The name of the file to be checked. In ISO8859-1 encoding.
      * @param   integer $maxlen The maximum length of the filename
-     * @return  string The 'safe' version of the filename
+     * @return  string The 'safe' version of the filename. Always in US-ASCII encoding.
      */
     function nameToSafe($name, $maxlen = 250)
     {
-        $noalpha = '@';
+        // using hex bytes as these need to be *bytes*, not dependant on sourcefile encoding.
+        $noalpha = "\xe1\xe9\xed\xf3\xfa\xe0\xe8\xec\xf2\xf9\xe4\xeb\xef\xf6\xfc\xc1\xc9\xcd\xd3\xda\xc0\xc8\xcc\xd2\xd9\xc4\xcb\xcf\xd6\xdc\xe2\xea\xee\xf4\xfb\xc2\xca\xce\xd4\xdb\xf1\xe7\xc7\x40";
         $alpha = 'aeiouaeiouaeiouAEIOUAEIOUAEIOUaeiouAEIOUncCa';
         $name = substr($name, 0, $maxlen);
         $name = strtr($name, $noalpha, $alpha);
@@ -617,4 +630,3 @@ class Attachment
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Attachment Class');
 }
-?>
\ No newline at end of file
