@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,18 +22,18 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.date.php 1.18 03/12/31 17:29:00-00:00 jpradomaia $
+// @(#) $Id: class.date.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
 // this line needed to make sure PEAR knows all eventum dates are stored as UTC (GMT).
 $_DATE_TIMEZONE_DEFAULT = 'UTC';
 
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_PEAR_PATH . "Date.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_PEAR_PATH . "Date.php");
 
 if (!defined('APP_DEFAULT_TIMEZONE')) {
     define('APP_DEFAULT_TIMEZONE', 'UTC');
@@ -53,7 +53,7 @@ define("YEAR", MONTH * 12);
  * pages.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Date_API
@@ -403,4 +403,3 @@ class Date_API
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Date_API Class');
 }
-?>
\ No newline at end of file
