@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,22 +22,22 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.filter.php 1.18 04/01/08 15:36:38-00:00 jpradomaia $
+// @(#) $Id: class.filter.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.date.php");
 
 /**
  * Class to handle the business logic related to the custom filters.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Filter
@@ -74,7 +74,7 @@ class Filter
 
 
     /**
-     * Method used to check whether the given user is the owner of the custom 
+     * Method used to check whether the given user is the owner of the custom
      * filter ID.
      *
      * @access  public
@@ -106,7 +106,7 @@ class Filter
 
 
     /**
-     * Method used to save the changes made to an existing custom 
+     * Method used to save the changes made to an existing custom
      * filter, or to create a new custom filter.
      *
      * @access  public
@@ -114,9 +114,7 @@ class Filter
      */
     function save()
     {
-        global $HTTP_POST_VARS;
-
-        $cst_id = Filter::getFilterID($HTTP_POST_VARS["title"]);
+        $cst_id = Filter::getFilterID($_POST["title"]);
         // loop through all available date fields and prepare the values for the sql query
         $date_fields = array(
             'created_date',
@@ -129,11 +127,11 @@ class Filter
             $date_var = $field_name;
             $filter_type_var = $field_name . '_filter_type';
             $date_end_var = $field_name . '_end';
-            if (@$HTTP_POST_VARS['filter'][$field_name] == 'yes') {
-                $$date_var = "'" . Misc::escapeString($HTTP_POST_VARS[$field_name]["Year"] . "-" . $HTTP_POST_VARS[$field_name]["Month"] . "-" . $HTTP_POST_VARS[$field_name]["Day"]) . "'";
-                $$filter_type_var = "'" . $HTTP_POST_VARS[$field_name]['filter_type'] . "'";
+            if (@$_POST['filter'][$field_name] == 'yes') {
+                $$date_var = "'" . Misc::escapeString($_POST[$field_name]["Year"] . "-" . $_POST[$field_name]["Month"] . "-" . $_POST[$field_name]["Day"]) . "'";
+                $$filter_type_var = "'" . $_POST[$field_name]['filter_type'] . "'";
                 if ($$filter_type_var == "'between'") {
-                    $$date_end_var = "'" . Misc::escapeString($HTTP_POST_VARS[$date_end_var]["Year"] . "-" . $HTTP_POST_VARS[$date_end_var]["Month"] . "-" . $HTTP_POST_VARS[$date_end_var]["Day"]) . "'";
+                    $$date_end_var = "'" . Misc::escapeString($_POST[$date_end_var]["Year"] . "-" . $_POST[$date_end_var]["Month"] . "-" . $_POST[$date_end_var]["Day"]) . "'";
                 } elseif (($$filter_type_var == "'null'") || ($$filter_type_var == "'in_past'")) {
                     $$date_var = "NULL";
                     $$date_end_var = "NULL";
@@ -146,41 +144,41 @@ class Filter
                 $$date_end_var = 'NULL';
             }
         }
-        
+
         // save custom fields to search
-        if ((is_array($HTTP_POST_VARS['custom_field'])) && (count($HTTP_POST_VARS['custom_field']) > 0)) {
-            foreach ($HTTP_POST_VARS['custom_field'] as $fld_id => $search_value) {
+        if ((is_array($_POST['custom_field'])) && (count($_POST['custom_field']) > 0)) {
+            foreach ($_POST['custom_field'] as $fld_id => $search_value) {
                 if (empty($search_value)) {
-                    unset($HTTP_POST_VARS[$fld_id]);
+                    unset($_POST[$fld_id]);
                 }
             }
-            $custom_field_string = serialize($HTTP_POST_VARS['custom_field']);
+            $custom_field_string = serialize($_POST['custom_field']);
         } else {
             $custom_field_string = '';
         }
-        
-        if (empty($HTTP_POST_VARS['is_global'])) {
+
+        if (empty($_POST['is_global'])) {
             $is_global_filter = 0;
         } else {
-            $is_global_filter = $HTTP_POST_VARS['is_global'];
+            $is_global_filter = $_POST['is_global'];
         }
         if ($cst_id != 0) {
             $stmt = "UPDATE
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_filter
                      SET
-                        cst_iss_pri_id='" . Misc::escapeInteger($HTTP_POST_VARS["priority"]) . "',
-                        cst_keywords='" . Misc::escapeString($HTTP_POST_VARS["keywords"]) . "',
-                        cst_users='" . Misc::escapeString($HTTP_POST_VARS["users"]) . "',
-                        cst_reporter=" . Misc::escapeInteger($HTTP_POST_VARS["reporter"]) . ",
-                        cst_iss_sta_id='" . Misc::escapeInteger($HTTP_POST_VARS["status"]) . "',
-                        cst_iss_pre_id='" . Misc::escapeInteger(@$HTTP_POST_VARS["release"]) . "',
-                        cst_iss_prc_id='" . Misc::escapeInteger(@$HTTP_POST_VARS["category"]) . "',
-                        cst_rows='" . Misc::escapeString($HTTP_POST_VARS["rows"]) . "',
-                        cst_sort_by='" . Misc::escapeString($HTTP_POST_VARS["sort_by"]) . "',
-                        cst_sort_order='" . Misc::escapeString($HTTP_POST_VARS["sort_order"]) . "',
-                        cst_hide_closed='" . Misc::escapeInteger(@$HTTP_POST_VARS["hide_closed"]) . "',
-                        cst_show_authorized='" . Misc::escapeString(@$HTTP_POST_VARS["show_authorized_issues"]) . "',
-                        cst_show_notification_list='" . Misc::escapeString(@$HTTP_POST_VARS["show_notification_list_issues"]) . "',
+                        cst_iss_pri_id='" . Misc::escapeInteger($_POST["priority"]) . "',
+                        cst_keywords='" . Misc::escapeString($_POST["keywords"]) . "',
+                        cst_users='" . Misc::escapeString($_POST["users"]) . "',
+                        cst_reporter=" . Misc::escapeInteger($_POST["reporter"]) . ",
+                        cst_iss_sta_id='" . Misc::escapeInteger($_POST["status"]) . "',
+                        cst_iss_pre_id='" . Misc::escapeInteger(@$_POST["release"]) . "',
+                        cst_iss_prc_id='" . Misc::escapeInteger(@$_POST["category"]) . "',
+                        cst_rows='" . Misc::escapeString($_POST["rows"]) . "',
+                        cst_sort_by='" . Misc::escapeString($_POST["sort_by"]) . "',
+                        cst_sort_order='" . Misc::escapeString($_POST["sort_order"]) . "',
+                        cst_hide_closed='" . Misc::escapeInteger(@$_POST["hide_closed"]) . "',
+                        cst_show_authorized='" . Misc::escapeString(@$_POST["show_authorized_issues"]) . "',
+                        cst_show_notification_list='" . Misc::escapeString(@$_POST["show_notification_list_issues"]) . "',
                         cst_created_date=$created_date,
                         cst_created_date_filter_type=$created_date_filter_type,
                         cst_created_date_time_period='" . @Misc::escapeInteger(@$_REQUEST['created_date']['time_period']) . "',
@@ -202,7 +200,7 @@ class Filter
                         cst_closed_date_time_period='" . @Misc::escapeInteger(@$_REQUEST['closed_date']['time_period']) . "',
                         cst_closed_date_end=" . Misc::escapeString($closed_date_end) . ",
                         cst_is_global=" . Misc::escapeInteger($is_global_filter) . ",
-                        cst_search_type='" . Misc::escapeString($HTTP_POST_VARS['search_type']) . "',
+                        cst_search_type='" . Misc::escapeString($_POST['search_type']) . "',
                         cst_custom_field='" . Misc::escapeString($custom_field_string) . "'
                      WHERE
                         cst_id=$cst_id";
@@ -252,20 +250,20 @@ class Filter
                      ) VALUES (
                         " . Auth::getUserID() . ",
                         " . Auth::getCurrentProject() . ",
-                        '" . Misc::escapeString($HTTP_POST_VARS["title"]) . "',
-                        '" . Misc::escapeInteger($HTTP_POST_VARS["priority"]) . "',
-                        '" . Misc::escapeString($HTTP_POST_VARS["keywords"]) . "',
-                        '" . Misc::escapeString($HTTP_POST_VARS["users"]) . "',
-                        '" . Misc::escapeInteger($HTTP_POST_VARS["reporter"]) . "',
-                        '" . Misc::escapeInteger($HTTP_POST_VARS["status"]) . "',
-                        '" . Misc::escapeInteger(@$HTTP_POST_VARS["release"]) . "',
-                        '" . Misc::escapeInteger(@$HTTP_POST_VARS["category"]) . "',
-                        '" . Misc::escapeString($HTTP_POST_VARS["rows"]) . "',
-                        '" . Misc::escapeString($HTTP_POST_VARS["sort_by"]) . "',
-                        '" . Misc::escapeString($HTTP_POST_VARS["sort_order"]) . "',
-                        '" . Misc::escapeInteger(@$HTTP_POST_VARS["hide_closed"]) . "',
-                        '" . Misc::escapeString(@$HTTP_POST_VARS["show_authorized_issues"]) . "',
-                        '" . Misc::escapeString(@$HTTP_POST_VARS["show_notification_list_issues"]) . "',
+                        '" . Misc::escapeString($_POST["title"]) . "',
+                        '" . Misc::escapeInteger($_POST["priority"]) . "',
+                        '" . Misc::escapeString($_POST["keywords"]) . "',
+                        '" . Misc::escapeString($_POST["users"]) . "',
+                        '" . Misc::escapeInteger($_POST["reporter"]) . "',
+                        '" . Misc::escapeInteger($_POST["status"]) . "',
+                        '" . Misc::escapeInteger(@$_POST["release"]) . "',
+                        '" . Misc::escapeInteger(@$_POST["category"]) . "',
+                        '" . Misc::escapeString($_POST["rows"]) . "',
+                        '" . Misc::escapeString($_POST["sort_by"]) . "',
+                        '" . Misc::escapeString($_POST["sort_order"]) . "',
+                        '" . Misc::escapeInteger(@$_POST["hide_closed"]) . "',
+                        '" . Misc::escapeString(@$_POST["show_authorized_issues"]) . "',
+                        '" . Misc::escapeString(@$_POST["show_notification_list_issues"]) . "',
                         $created_date,
                         $created_date_filter_type,
                         '" . @Misc::escapeInteger(@$_REQUEST['created_date']['time_period']) . "',
@@ -287,7 +285,7 @@ class Filter
                         '" . @Misc::escapeInteger(@$_REQUEST['closed_date']['time_period']) . "',
                         $closed_date_end,
                         " . Misc::escapeInteger($is_global_filter) . ",
-                        '" . Misc::escapeString($HTTP_POST_VARS['search_type']) . "',
+                        '" . Misc::escapeString($_POST['search_type']) . "',
                         '" . Misc::escapeString($custom_field_string) . "'
                      )";
         }
@@ -330,8 +328,8 @@ class Filter
 
 
     /**
-     * Method used to get an associative array of the full list of 
-     * custom filters (filter id => filter title) associated with the 
+     * Method used to get an associative array of the full list of
+     * custom filters (filter id => filter title) associated with the
      * current user and the current 'active' project.
      *
      * @access  public
@@ -364,7 +362,7 @@ class Filter
 
     /**
      * Method used to get an array of the full list of the custom
-     * filters associated with the current user and the current 
+     * filters associated with the current user and the current
      * 'active' project.
      *
      * @access  public
@@ -424,16 +422,16 @@ class Filter
                     $res[$i]['url'] .= 'custom_field=' . urlencode($res[$i]['cst_custom_field']);
                 }
             }
-            
+
             return $res;
         }
     }
-    
-    
+
+
     /**
      * Takes the saved search details and information about filters and returns an array of
      * of the saved search information.
-     * 
+     *
      * @access  private
      * @param   array $details An array of information about the saved search, usually the direct row from the database.
      * @param   array $info An array of information about filters
@@ -475,7 +473,7 @@ class Filter
 
 
     /**
-     * Method used to get an associative array of the full details of 
+     * Method used to get an associative array of the full details of
      * a specific custom filter.
      *
      * @access  public
@@ -518,10 +516,8 @@ class Filter
      */
     function remove()
     {
-        global $HTTP_POST_VARS;
-
-        $items = implode(", ", Misc::escapeInteger($HTTP_POST_VARS["item"]));
-        foreach ($HTTP_POST_VARS["item"] as $cst_id) {
+        $items = implode(", ", Misc::escapeInteger($_POST["item"]));
+        foreach ($_POST["item"] as $cst_id) {
             $stmt = "DELETE FROM
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "custom_filter
                      WHERE";
@@ -529,7 +525,7 @@ class Filter
                 if (Auth::getCurrentRole() >= User::getRoleID('Manager')) {
                     $stmt .= " cst_is_global=1 AND ";
                 } else {
-                    $stmt .= " 
+                    $stmt .= "
                         cst_is_global=1 AND
                         cst_usr_id=" . Auth::getUserID() . " AND ";
                 }
@@ -572,11 +568,11 @@ class Filter
             return true;
         }
     }
-    
-    
+
+
     /**
      * Returns an array of information about all the different filter fields.
-     * 
+     *
      * @access  public
      * @return  Array an array of information.
      */
@@ -587,93 +583,93 @@ class Filter
         //      "param" => name that appears in get, post or cookie
         $fields = array(
             'iss_pri_id'    =>  array(
-                'title' =>  'Priority',
+                'title' =>  ev_gettext("Priority"),
                 'param' =>  'priority',
                 'quickfilter'   =>  true
             ),
             'keywords'  =>  array(
-                'title' =>  'Keyword(s)',
+                'title' =>  ev_gettext("Keyword(s)"),
                 'param' =>  'keywords',
                 'quickfilter'   =>  true
             ),
             'users' =>  array(
-                'title' =>  'Assigned',
+                'title' =>  ev_gettext("Assigned"),
                 'param' =>  'users',
                 'quickfilter'   =>  true
             ),
             'iss_prc_id'    =>  array(
-                'title' =>  'Category',
+                'title' =>  ev_gettext("Category"),
                 'param' =>  'category',
                 'quickfilter'   =>  true
             ),
             'iss_sta_id'    =>  array(
-                'title' =>  'Status',
+                'title' =>  ev_gettext("Status"),
                 'param' =>  'status',
                 'quickfilter'   =>  true
             ),
             'iss_pre_id'    =>  array(
-                'title' =>  'Release',
+                'title' =>  ev_gettext("Release"),
                 'param' =>  'release'
             ),
             'created_date'  =>  array(
-                'title' =>  'Created Date',
+                'title' =>  ev_gettext("Created Date"),
                 'param' =>  'created_date',
                 'is_date'   =>  true
             ),
             'updated_date'  =>  array(
-                'title' =>  'Updated Date',
+                'title' =>  ev_gettext("Updated Date"),
                 'param' =>  'updated_date',
                 'is_date'   =>  true
             ),
             'last_response_date'  =>  array(
-                'title' =>  'Last Response Date',
+                'title' =>  ev_gettext("Last Response Date"),
                 'param' =>  'last_response_date',
                 'is_date'   =>  true
             ),
             'first_response_date'  =>  array(
-                'title' =>  'First Response Date',
+                'title' =>  ev_gettext("First Response Date"),
                 'param' =>  'first_response_date',
                 'is_date'   =>  true
             ),
             'closed_date'  =>  array(
-                'title' =>  'Closed Date',
+                'title' =>  ev_gettext("Closed Date"),
                 'param' =>  'closed_date',
                 'is_date'   =>  true
             ),
             'rows'  =>  array(
-                'title' =>  'Rows Per Page',
+                'title' =>  ev_gettext("Rows Per Page"),
                 'param' =>  'rows'
             ),
             'sort_by'   =>  array(
-                'title' =>  'Sort By',
+                'title' =>  ev_gettext("Sort By"),
                 'param' =>  'sort_by'
             ),
             'sort_order'    =>  array(
-                'title' =>  'Sort Order',
+                'title' =>  ev_gettext("Sort Order"),
                 'param' =>  'sort_order',
             ),
             'hide_closed'   =>  array(
-                'title' =>  'Hide Closed Issues',
+                'title' =>  ev_gettext("Hide Closed Issues"),
                 'param' =>  'hide_closed'
             ),
             'show_authorized'   =>  array(
-                'title' =>  'Authorized to Send Emails',
+                'title' =>  ev_gettext("Authorized to Send Emails"),
                 'param' =>  'show_authorized_issues'
             ),
             'show_notification_list'    =>  array(
-                'title' =>  'In Notification List',
+                'title' =>  ev_gettext("In Notification List"),
                 'param' =>  'show_notification_list_issues'
             ),
             'search_type'   =>  array(
-                'title' =>  'Search Type',
+                'title' =>  ev_gettext("Search Type"),
                 'param' =>  'search_type'
             ),
             'reporter'  =>  array(
-                'title' =>  'Reporter',
+                'title' =>  ev_gettext("Reporter"),
                 'param' =>  'reporter'
             )
         );
-        
+
         // add custom fields
         $custom_fields = Custom_Field::getFieldsByProject(Auth::getCurrentProject());
         if (count($custom_fields) > 0) {
@@ -687,7 +683,7 @@ class Filter
                 );
             }
         }
-            
+
         return $fields;
     }
 }
@@ -696,4 +692,3 @@ class Filter
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Filter Class');
 }
-?>
\ No newline at end of file
