@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,23 +22,23 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.history.php 1.15 03/12/31 17:29:00-00:00 jpradomaia $
+// @(#) $Id: class.history.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.mime_helper.php");
-include_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.mime_helper.php");
+require_once(APP_INC_PATH . "class.date.php");
 
 /**
  * Class to handle the business logic related to the history information for
  * the issues entered in the system.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class History
@@ -215,10 +215,24 @@ class History
      * @param   date $start The start date
      * @param   date $end The end date
      * @param   date $separate_closed If closed issues should be included in a separate array
+     * @param   array $htt_exclude Addtional History Types to ignore
      * @return  array An array of issues touched by the user.
      */
-    function getTouchedIssuesByUser($usr_id, $start, $end, $separate_closed = false)
+    function getTouchedIssuesByUser($usr_id, $start, $end, $separate_closed = false, $htt_exclude = array())
     {
+
+        $htt_list = History::getTypeID(
+            array_merge(array(
+                'notification_removed',
+                'notification_added',
+                'notification_updated',
+                'remote_replier_added',
+                'replier_added',
+                'replier_removed',
+                'replier_other_added',
+            ), $htt_exclude)
+        );
+
         $stmt = "SELECT
                     iss_id,
                     iss_prj_id,
@@ -236,16 +250,12 @@ class History
                     his_iss_id = iss_id AND
                     his_usr_id = " . Misc::escapeInteger($usr_id) . " AND
                     his_created_date BETWEEN '" . Misc::escapeString($start) . "' AND '" . Misc::escapeString($end) . "' AND
-                    his_htt_id NOT IN(" . join(',', History::getTypeID(array(
-                        'notification_removed',
-                        'notification_added',
-                        'notification_updated',
-                        'remote_replier_added',
-                        'replier_added',
-                        'replier_removed',
-                        'replier_other_added'))) . ")
+                    his_htt_id NOT IN(" . join(',', $htt_list) . ") AND
+                    iss_prj_id = " . Auth::getCurrentProject() . "
                  GROUP BY
-                    iss_id";
+                    iss_id
+                 ORDER BY
+                    iss_id ASC";
         $res = $GLOBALS["db_api"]->dbh->getAll($stmt, DB_FETCHMODE_ASSOC);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -298,6 +308,7 @@ class History
                  WHERE
                     his_iss_id = iss_id AND
                     iss_sta_id = sta_id AND
+                    iss_prj_id = " . Auth::getCurrentProject() . " AND
                     his_usr_id = " . Misc::escapeInteger($usr_id) . " AND
                     his_created_date BETWEEN '" . Misc::escapeString($start) . "' AND '" . Misc::escapeString($end) . "'";
         if ($statuses != false) {
@@ -389,4 +400,3 @@ class History
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included History Class');
 }
-?>
\ No newline at end of file
