@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,17 +22,17 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-//
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.mail_queue.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.mime_helper.php");
-include_once(APP_INC_PATH . "class.reminder.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.mail_queue.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.mime_helper.php");
+require_once(APP_INC_PATH . "class.reminder.php");
+require_once(APP_PEAR_PATH . "Mail/RFC822.php");
 
 /**
  * Class to handle the business logic related to sending email to
@@ -41,7 +41,7 @@ include_once(APP_INC_PATH . "class.reminder.php");
  * different platforms.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Mail_API
@@ -62,8 +62,8 @@ class Mail_API
      */
     function Mail_API()
     {
-        @include_once(APP_PEAR_PATH . 'Mail.php');
-        @include_once(APP_PEAR_PATH . 'Mail/mime.php');
+        @require_once(APP_PEAR_PATH . 'Mail.php');
+        @require_once(APP_PEAR_PATH . 'Mail/mime.php');
         $this->mime = new Mail_mime("\r\n");
     }
 
@@ -116,43 +116,13 @@ class Mail_API
      */
     function getCannedBlockedMsgExplanation()
     {
-        $msg = "WARNING: This message was blocked because the sender was not allowed to send emails to the associated issue. ";
-        $msg .= "Only staff members listed in the assignment or authorized replier fields can send emails.\n";
+        $msg = ev_gettext("WARNING: This message was blocked because the sender was not allowed to send emails to the associated issue.") . " ";
+        $msg .= ev_gettext("Only staff members listed in the assignment or authorized replier fields can send emails.") . "\n";
         $msg .= str_repeat('-', 70) . "\n\n";
         return $msg;
     }
 
 
-    /**
-     * Checks whether the given string contains the magic cookie or not.
-     *
-     * @access  public
-     * @param   string $message The email message
-     * @return  boolean
-     */
-    function hasMagicCookie($message)
-    {
-        if (strstr($message, 'really-send-this-mail')) {
-            return true;
-        } else {
-            return false;
-        }
-    }
-
-
-    /**
-     * Returns the given string without the magic cookie, if any.
-     *
-     * @access  public
-     * @param   string $message The email message
-     * @return  string The message without the magic cookie
-     */
-    function stripMagicCookie($message)
-    {
-        return str_replace('really-send-this-mail', '', $message);
-    }
-
-
     /**
      * Checks whether the given headers are from a vacation
      * auto-responder message or not.
@@ -168,7 +138,7 @@ class Mail_API
             $headers[strtolower($key)] = $value;
         }
 
-        if (@$headers['x-vacationmessage'] == 'Yes') {
+        if ((@$headers['x-vacationmessage'] == 'Yes') || (@$headers['auto-submitted'] == 'auto-replied (vacation)')) {
             return true;
         } else {
             return false;
@@ -209,24 +179,38 @@ class Mail_API
      */
     function fixAddressQuoting($address)
     {
-        // check if we have a <
-        if ((strstr($address, '<')) && (!Mime_Helper::isQuotedPrintable($address))) {
-            $address = stripslashes($address);
-            // is the address in the format 'name' <address> ?
-            if ((strstr($address, "'")) || (strstr($address, "."))) {
-                $first_part = substr($address, 0, strpos($address, '<') - 1);
-                $first_part = '"' . $first_part . '"';
-                $second_part = substr($address, strpos($address, '<'));
-                $address = $first_part . ' ' . $second_part;
-                // if the address was already in the format "'name'" <address>, then this code
-                // will end up adding even more double quotes, so let's remove any excess
-                return str_replace('""', '"', $address);
+        // split multiple addresses if needed
+        $addresses = Mail_API::splitAddresses($address);
+
+        $return = array();
+        foreach ($addresses as $address) {
+            // check if we have a <
+            if ((strstr($address, '<')) && (!Mime_Helper::isQuotedPrintable($address))) {
+                $address = stripslashes(trim($address));
+                // is the address in the format 'name' <address> ?
+                if ((strstr($address, "'")) || (strstr($address, "."))) {
+                    $bracket_pos = strpos($address, '<');
+                    if ($bracket_pos != 0) {
+                        $bracket_pos = $bracket_pos - 1;
+                    }
+                    $first_part = substr($address, 0, $bracket_pos);
+                    if (!empty($first_part)) {
+                        $first_part = '"' . str_replace('"', '\"', preg_replace("/(^\")|(\"$)/", '', $first_part)) . '"';
+                    }
+                    $second_part = substr($address, strpos($address, '<'));
+                    $address = $first_part . ' ' . $second_part;
+                    // if the address was already in the format "'name'" <address>, then this code
+                    // will end up adding even more double quotes, so let's remove any excess
+                    $return[] = str_replace('""', '"', $address);
+                } else {
+                    $return[] = $address;
+                }
             } else {
-                return $address;
+                $return[] = $address;
             }
-        } else {
-            return $address;
         }
+
+        return join(',', $return);
     }
 
 
@@ -243,14 +227,16 @@ class Mail_API
     {
         $address = Mail_API::fixAddressQuoting($address);
         $address = Mime_Helper::encodeValue($address);
-        include_once(APP_PEAR_PATH . "Mail/RFC822.php");
         $t = Mail_RFC822::parseAddressList($address, null, null, false);
+        if (PEAR::isError($t)) {
+            Error_Handler::logError(array($t->getMessage(), $t->getDebugInfo()), __FILE__, __LINE__);
+        }
         if ($multiple) {
             $returns = array();
             for ($i = 0; $i < count($t); $i++) {
                 $returns[] = array(
                     'sender_name' => $t[$i]->personal,
-                    'email'       => $t[$i]->mailbox . '@' . $t[0]->host,
+                    'email'       => $t[$i]->mailbox . '@' . $t[$i]->host,
                     'username'    => $t[$i]->mailbox,
                     'host'        => $t[$i]->host
                 );
@@ -296,6 +282,9 @@ class Mail_API
         $returns = array();
         foreach ($info as $row) {
             if (!empty($row['sender_name'])) {
+                if ((substr($row['sender_name'], 0, 1) == '"') && (substr($row['sender_name'], -1) == '"')) {
+                    $row['sender_name'] = substr($row['sender_name'], 1, -1);
+                }
                 $returns[] = Mime_Helper::fixEncoding($row['sender_name']);
             } else {
                 $returns[] = $row['email'];
@@ -471,9 +460,9 @@ class Mail_API
     function getWarningMessage($type)
     {
         if ($type == 'allowed') {
-            $str = 'ADVISORY: Your reply will be sent to the notification list.';
+            $str = ev_gettext("ADVISORY: Your reply will be sent to the notification list.");
         } else {
-            $str = 'WARNING: If replying, add yourself to Authorized Repliers list first.';
+            $str = ev_gettext("WARNING: If replying, add yourself to Authorized Repliers list first.");
         }
         return $str;
     }
@@ -561,7 +550,7 @@ class Mail_API
         $to = MIME_Helper::encodeAddress($to);
         $subject = MIME_Helper::encode($subject);
 
-        $body = $this->mime->get();
+        $body = $this->mime->get(array('text_charset' => APP_CHARSET, 'head_charset' => APP_CHARSET, 'text_encoding' => APP_EMAIL_ENCODING));
         $headers = array(
             'From'    => $from,
             'To'      => Mail_API::fixAddressQuoting($to),
@@ -602,7 +591,7 @@ class Mail_API
         $to = MIME_Helper::encodeAddress($to);
         $subject = MIME_Helper::encode($subject);
 
-        $body = $this->mime->get();
+        $body = $this->mime->get(array('text_charset' => APP_CHARSET, 'head_charset' => APP_CHARSET, 'text_encoding' => APP_EMAIL_ENCODING));
         $this->setHeaders(array(
             'From'    => $from,
             'To'      => $to,
@@ -749,6 +738,9 @@ class Mail_API
                     $new_headers['X-Eventum-Level'] = $support_levels[Customer::getSupportLevelID($prj_id, $customer_id)];
                 }
             }
+            // add assignee header
+            $new_headers['X-Eventum-Assignee'] = join(',', User::getEmail(Issue::getAssignedUserIDs($issue_id)));
+
             $new_headers['X-Eventum-Category'] = Category::getTitle(Issue::getCategory($issue_id));
             $new_headers['X-Eventum-Project'] = Project::getName($prj_id);
         }
@@ -986,10 +978,25 @@ class Mail_API
         }
 
     }
+
+
+    function splitAddresses($addresses)
+    {
+        $mail = new Mail_RFC822($addresses);
+
+        $mail->parseAddressList();
+
+        $return = array();
+        if (is_array($mail->addresses)) {
+            foreach ($mail->addresses as $address) {
+                $return[] = $address['address'];
+            }
+        }
+        return $return;
+    }
 }
 
 // benchmarking the included file (aka setup time)
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Mail_API Class');
 }
-?>
\ No newline at end of file
