@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,20 +22,18 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
 
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.mime_helper.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.lock.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_PEAR_PATH . 'Mail.php');
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.mime_helper.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.lock.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_PEAR_PATH . 'Mail.php');
 
 class Mail_Queue
 {
@@ -112,7 +110,12 @@ class Mail_Queue
             $headers['To'] = Mail_API::fixAddressQuoting($headers['To']);
         }
 
-        list(,$text_headers) = Mail_API::prepareHeaders($headers);
+        $prepared_headers = Mail_API::prepareHeaders($headers);
+        if (PEAR::isError($prepared_headers)) {
+            print_r(debug_backtrace());
+            return;
+        }
+        list(,$text_headers) = $prepared_headers;
 
         $stmt = "INSERT INTO
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "mail_queue
@@ -135,7 +138,7 @@ class Mail_Queue
         $stmt .= ") VALUES (
                     $save_email_copy,
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . getenv("REMOTE_ADDR") . "',
+                    '" . @$_SERVER['REMOTE_ADDR'] . "',
                     '" . Misc::escapeString($recipient) . "',
                     '" . Misc::escapeString($text_headers) . "',
                     '" . Misc::escapeString($body) . "',
@@ -174,7 +177,11 @@ class Mail_Queue
         $emails = Mail_Queue::_getList($status, $limit);
         // foreach email
         for ($i = 0; $i < count($emails); $i++) {
-            $result = Mail_Queue::_sendEmail($emails[$i]['recipient'], $emails[$i]['headers'], $emails[$i]['body']);
+            $current_status = $status;
+            if ($emails[$i]['maq_type'] == 'error') {
+                $current_status = 'error';
+            }
+            $result = Mail_Queue::_sendEmail($emails[$i]['recipient'], $emails[$i]['headers'], $emails[$i]['body'], $current_status);
             if (PEAR::isError($result)) {
                 Mail_Queue::_saveLog($emails[$i]['id'], 'error', Mail_Queue::_getErrorMessage($result));
             } else {
@@ -195,9 +202,10 @@ class Mail_Queue
      * @param   string $recipient The recipient of this message
      * @param   string $text_headers The full headers of this message
      * @param   string $body The full body of this message
+     * @param   string $status The status of this message
      * @return  true, or a PEAR_Error object
      */
-    function _sendEmail($recipient, $text_headers, $body)
+    function _sendEmail($recipient, $text_headers, $body, $status)
     {
         $header_names = Mime_Helper::getHeaderNames($text_headers);
         $_headers = Mail_Queue::_getHeaders($text_headers, $body);
@@ -228,7 +236,7 @@ class Mail_Queue
         $res = $mail->send($recipient, $headers, $body);
         if (PEAR::isError($res)) {
             // special handling of errors when the mail server is down
-            if (strstr($res->getMessage(), 'unable to connect to smtp server')) {
+            if (($status == 'error') || (strstr($res->getMessage(), 'unable to connect to smtp server')) || (stristr($res->getMessage(), 'Failed to connect to') !== false)) {
                 Error_Handler::logToFile(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             } else {
                 Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -316,8 +324,8 @@ class Mail_Queue
                  ) VALUES (
                     $maq_id,
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '$status',
-                    '$server_message'
+                    '" . Misc::escapeString($status) . "',
+                    '" . Misc::escapeString($server_message) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -327,7 +335,7 @@ class Mail_Queue
             $stmt = "UPDATE
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "mail_queue
                      SET
-                        maq_status='$status'
+                        maq_status='" . Misc::escapeString($status) . "'
                      WHERE
                         maq_id=$maq_id";
             $GLOBALS["db_api"]->dbh->query($stmt);
@@ -445,4 +453,3 @@ class Mail_Queue
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Mail_Queue Class');
 }
-?>
\ No newline at end of file
