@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,7 +22,7 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
 
@@ -32,23 +32,23 @@
  * notifications on actions regarding the issues.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_INC_PATH . "class.custom_field.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.mail.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.history.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.priority.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_INC_PATH . "class.custom_field.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.mail.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.priority.php");
 
 class Notification
 {
@@ -341,14 +341,14 @@ class Notification
         $headers["Subject"] = Mail_API::formatSubject($issue_id, $headers['Subject']);
 
         if (empty($type)) {
-            if (User::getRoleByUser($usr_id, Issue::getProjectID($issue_id)) == User::getRoleID("Customer")) {
+            if (($sender_usr_id != false) && (User::getRoleByUser($sender_usr_id, Issue::getProjectID($issue_id)) == User::getRoleID("Customer"))) {
                 $type = 'customer_email';
             } else {
                 $type = 'other_email';
             }
         }
 
-        @include_once(APP_PEAR_PATH . 'Mail/mime.php');
+        @require_once(APP_PEAR_PATH . 'Mail/mime.php');
         foreach ($emails as $to) {
             $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($to));
             $to = MIME_Helper::encodeAddress($to);
@@ -616,47 +616,47 @@ class Notification
             }
             $assign_diff = Misc::arrayDiff($old['assigned_users'], $new['assignments']);
             if (count($assign_diff) > 0) {
-                $diffs[] = '-Assignment List: ' . $old['assignments'];
-                @$diffs[] = '+Assignment List: ' . implode(', ', User::getFullName($new['assignments']));
+                $diffs[] = '-' . ev_gettext('Assignment List') . ': ' . $old['assignments'];
+                @$diffs[] = '+' . ev_gettext('Assignment List') . ': ' . implode(', ', User::getFullName($new['assignments']));
             }
         }
         if (@$old['iss_expected_resolution_date'] != $new['expected_resolution_date']) {
-            $diffs[] = '-Expected Resolution Date: ' . $old['iss_expected_resolution_date'];
-            $diffs[] = '+Expected Resolution Date: ' . $new['expected_resolution_date'];
+            $diffs[] = '-' . ev_gettext('Expected Resolution Date') . ': ' . $old['iss_expected_resolution_date'];
+            $diffs[] = '+' . ev_gettext('Expected Resolution Date') . ': ' . $new['expected_resolution_date'];
         }
         if ($old["iss_prc_id"] != $new["category"]) {
-            $diffs[] = '-Category: ' . Category::getTitle($old["iss_prc_id"]);
-            $diffs[] = '+Category: ' . Category::getTitle($new["category"]);
+            $diffs[] = '-' . ev_gettext('Category') . ': ' . Category::getTitle($old["iss_prc_id"]);
+            $diffs[] = '+' . ev_gettext('Category') . ': ' . Category::getTitle($new["category"]);
         }
         if ((@$new["keep"] == "no") && ($old["iss_pre_id"] != $new["release"])) {
-            $diffs[] = '-Release: ' . Release::getTitle($old["iss_pre_id"]);
-            $diffs[] = '+Release: ' . Release::getTitle($new["release"]);
+            $diffs[] = '-' . ev_gettext('Release') . ': ' . Release::getTitle($old["iss_pre_id"]);
+            $diffs[] = '+' . ev_gettext('Release') . ': ' . Release::getTitle($new["release"]);
         }
         if ($old["iss_pri_id"] != $new["priority"]) {
-            $diffs[] = '-Priority: ' . Priority::getTitle($old["iss_pri_id"]);
-            $diffs[] = '+Priority: ' . Priority::getTitle($new["priority"]);
+            $diffs[] = '-' . ev_gettext('Priority') . ': ' . Priority::getTitle($old["iss_pri_id"]);
+            $diffs[] = '+' . ev_gettext('Priority') . ': ' . Priority::getTitle($new["priority"]);
         }
         if ($old["iss_sta_id"] != $new["status"]) {
-            $diffs[] = '-Status: ' . Status::getStatusTitle($old["iss_sta_id"]);
-            $diffs[] = '+Status: ' . Status::getStatusTitle($new["status"]);
+            $diffs[] = '-' . ev_gettext('Status') . ': ' . Status::getStatusTitle($old["iss_sta_id"]);
+            $diffs[] = '+' . ev_gettext('Status') . ': ' . Status::getStatusTitle($new["status"]);
         }
         if ($old["iss_res_id"] != $new["resolution"]) {
-            $diffs[] = '-Resolution: ' . Resolution::getTitle($old["iss_res_id"]);
-            $diffs[] = '+Resolution: ' . Resolution::getTitle($new["resolution"]);
+            $diffs[] = '-' . ev_gettext('Resolution') . ': ' . Resolution::getTitle($old["iss_res_id"]);
+            $diffs[] = '+' . ev_gettext('Resolution') . ': ' . Resolution::getTitle($new["resolution"]);
         }
         if ($old["iss_dev_time"] != $new["estimated_dev_time"]) {
-            $diffs[] = '-Estimated Dev. Time: ' . Misc::getFormattedTime($old["iss_dev_time"]*60);
-            $diffs[] = '+Estimated Dev. Time: ' . Misc::getFormattedTime($new["estimated_dev_time"]*60);
+            $diffs[] = '-' . ev_gettext('Estimated Dev. Time') . ': ' . Misc::getFormattedTime($old["iss_dev_time"]*60);
+            $diffs[] = '+' . ev_gettext('Estimated Dev. Time') . ': ' . Misc::getFormattedTime($new["estimated_dev_time"]*60);
         }
         if ($old["iss_summary"] != $new["summary"]) {
-            $diffs[] = '-Summary: ' . $old['iss_summary'];
-            $diffs[] = '+Summary: ' . $new['summary'];
+            $diffs[] = '-' . ev_gettext('Summary') . ': ' . $old['iss_summary'];
+            $diffs[] = '+' . ev_gettext('Summary') . ': ' . $new['summary'];
         }
         if ($old["iss_description"] != $new["description"]) {
             // need real diff engine here
-            include_once 'Text_Diff/Diff.php';
-            include_once 'Text_Diff/Diff/Renderer.php';
-            include_once 'Text_Diff/Diff/Renderer/unified.php';
+            require_once 'Text_Diff/Diff.php';
+            require_once 'Text_Diff/Diff/Renderer.php';
+            require_once 'Text_Diff/Diff/Renderer/unified.php';
             $old['iss_description'] = explode("\n", $old['iss_description']);
             $new['description'] = explode("\n", $new['description']);
             $diff = &new Text_Diff($old["iss_description"], $new["description"]);
@@ -676,6 +676,10 @@ class Notification
             if (empty($users[$i]["sub_usr_id"])) {
                 $email = $users[$i]["sub_email"];
             } else {
+                if (Auth::getUserID() == $users[$i]["sub_usr_id"]) {
+                    // don't notify the user who made this change
+                    continue;
+                }
                 $email = User::getFromHeader($users[$i]["sub_usr_id"]);
             }
             // now add it to the list of emails
@@ -686,7 +690,7 @@ class Notification
         $data = Notification::getIssueDetails($issue_id);
         $data['diffs'] = implode("\n", $diffs);
         $data['updated_by'] = User::getFullName(Auth::getUserID());
-        Notification::notifySubscribers($issue_id, $emails, 'updated', $data, 'Updated', FALSE);
+        Notification::notifySubscribers($issue_id, $emails, 'updated', $data, ev_gettext('Updated'), FALSE);
     }
 
 
@@ -719,6 +723,10 @@ class Notification
             if (empty($users[$i]["sub_usr_id"])) {
                 $email = $users[$i]["sub_email"];
             } else {
+                if (Auth::getUserID() == $users[$i]["sub_usr_id"]) {
+                    // don't notify the user who made this change
+                    continue;
+                }
                 $email = User::getFromHeader($users[$i]["sub_usr_id"]);
             }
             // now add it to the list of emails
@@ -809,7 +817,7 @@ class Notification
                 case 'closed':
                     $data = Notification::getIssueDetails($issue_id);
                     $data["closer_name"] = User::getFullName(History::getIssueCloser($issue_id));
-                    $subject = 'Closed';
+                    $subject = ev_gettext('Closed');
 
                     if ($ids != false) {
                         $data['reason'] = Support::getEmail($ids);
@@ -899,6 +907,13 @@ class Notification
                 continue;
             }
 
+            // change the current locale
+            if (!empty($recipient_usr_id)) {
+                Language::set(User::getLang($recipient_usr_id));
+            } else {
+                Language::set(APP_DEFAULT_LOCALE);
+            }
+
             // send email (use PEAR's classes)
             $mail = new Mail_API;
             $mail->setTextBody($tpl->getTemplateContents());
@@ -912,7 +927,7 @@ class Notification
             if ($type == 'notes') {
                 // special handling of blocked messages
                 if (!empty($data['note']['not_blocked_message'])) {
-                    $subject = 'BLOCKED';
+                    $subject = ev_gettext('BLOCKED');
                     $final_type = 'blocked_email';
                 }
                 if (!empty($data["note"]["not_unknown_user"])) {
@@ -947,6 +962,9 @@ class Notification
             }
             $mail->send($from, $emails[$i], $full_subject, TRUE, $issue_id, $final_type, $sender_usr_id, $type_id);
         }
+
+        // restore correct language
+        Language::restore();
     }
 
 
@@ -1056,7 +1074,7 @@ class Notification
         $irc_notice .= $data['iss_summary'];
         Notification::notifyIRC($prj_id, $irc_notice, $issue_id);
         $data['custom_fields'] = array();// empty place holder so notifySubscribers will fill it in with appropriate data for the user
-        $subject = 'New Issue';
+        $subject = ev_gettext('New Issue');
         $headers = array(
             "Message-ID"    =>  $data['iss_root_message_id']
         );
@@ -1074,14 +1092,24 @@ class Notification
      * @param   string $sender The sender of the email message (and the recipient of this notification)
      * @param   string $date The arrival date of the email message
      * @param   string $subject The subject line of the email message
+     * @param   string $additional_recipient The user who should recieve this email who is not the sender of the original email.
      * @return  void
      */
-    function notifyAutoCreatedIssue($prj_id, $issue_id, $sender, $date, $subject)
+    function notifyAutoCreatedIssue($prj_id, $issue_id, $sender, $date, $subject, $additional_recipient = false)
     {
         if (Customer::hasCustomerIntegration($prj_id)) {
             Customer::notifyAutoCreatedIssue($prj_id, $issue_id, $sender, $date, $subject);
         } else {
-            if (!Workflow::shouldEmailAddress($prj_id, Mail_API::getEmailAddress($sender))) {
+            if ($additional_recipient != false) {
+                $recipient = $additional_recipient;
+                $is_message_sender = false;
+            } else {
+                $recipient = $sender;
+                $is_message_sender = true;
+            }
+            $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($recipient));
+
+            if (!Workflow::shouldEmailAddress($prj_id, Mail_API::getEmailAddress($recipient))) {
                 return;
             }
             $data = Issue::getDetails($issue_id);
@@ -1092,7 +1120,9 @@ class Notification
             $tpl->bulkAssign(array(
                 "app_title"   => Misc::getToolCaption(),
                 "data"        => $data,
-                "sender_name" => Mail_API::getName($sender)
+                "sender_name" => Mail_API::getName($sender),
+                'recipient_name'    => Mail_API::getName($recipient),
+                'is_message_sender' =>  $is_message_sender
             ));
 
             // figure out if sender has a real account or not
@@ -1111,6 +1141,14 @@ class Notification
                     'subject' => $subject
                 )
             ));
+
+            // change the current locale
+            if (!empty($recipient_usr_id)) {
+                Language::set(User::getLang($recipient_usr_id));
+            } else {
+                Language::set(APP_DEFAULT_LOCALE);
+            }
+
             $text_message = $tpl->getTemplateContents();
 
             // send email (use PEAR's classes)
@@ -1119,8 +1157,10 @@ class Notification
             $mail->setHeaders(Mail_API::getBaseThreadingHeaders($issue_id));
             $setup = $mail->getSMTPSettings();
             $from = Notification::getFixedFromHeader($issue_id, $setup["from"], 'issue');
-            $sender = Mime_Helper::fixEncoding($sender);
-            $mail->send($from, $sender, "[#$issue_id] Issue Created: " . $data['iss_summary'], 0, $issue_id, 'auto_created_issue');
+            $recipient = Mime_Helper::fixEncoding($recipient);
+            $mail->send($from, $recipient, "[#$issue_id] Issue Created: " . $data['iss_summary'], 0, $issue_id, 'auto_created_issue');
+
+            Language::restore();
         }
     }
 
@@ -1159,6 +1199,9 @@ class Notification
 
             $data = Issue::getDetails($issue_id);
             foreach ($recipients as $sup_id => $recipient) {
+
+                $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($recipient));
+
                 // open text template
                 $tpl = new Template_API;
                 $tpl->setTemplate('notifications/new_auto_created_issue.tpl.text');
@@ -1174,6 +1217,14 @@ class Notification
                         'subject' => $email_details['sup_subject']
                     )
                 ));
+
+                // change the current locale
+                if (!empty($recipient_usr_id)) {
+                    Language::set(User::getLang($recipient_usr_id));
+                } else {
+                    Language::set(APP_DEFAULT_LOCALE);
+                }
+
                 $text_message = $tpl->getTemplateContents();
 
                 // send email (use PEAR's classes)
@@ -1184,6 +1235,7 @@ class Notification
                 $mail->setHeaders(Mail_API::getBaseThreadingHeaders($issue_id));
                 $mail->send($from, $recipient, 'New Issue Created', 1, $issue_id, 'email_converted_to_issue');
             }
+            Language::restore();
             return $recipient_emails;
         }
     }
@@ -1316,13 +1368,19 @@ class Notification
             "app_title"    => Misc::getToolCaption(),
             "user"         => $info
         ));
+
+        // change the current locale
+        Language::set(User::getLang($usr_id));
+
         $text_message = $tpl->getTemplateContents();
 
         // send email (use PEAR's classes)
         $mail = new Mail_API;
         $mail->setTextBody($text_message);
         $setup = $mail->getSMTPSettings();
-        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": User account information updated");
+        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": " . ev_gettext("User account information updated"));
+
+        Language::restore();
     }
 
 
@@ -1347,13 +1405,19 @@ class Notification
             "app_title"    => Misc::getToolCaption(),
             "user"         => $info
         ));
+
+        // change the current locale
+        Language::set(User::getLang($usr_id));
+
         $text_message = $tpl->getTemplateContents();
 
         // send email (use PEAR's classes)
         $mail = new Mail_API;
         $mail->setTextBody($text_message);
         $setup = $mail->getSMTPSettings();
-        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": User account password changed");
+        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": " . ev_gettext("User account password changed"));
+
+        Language::restore();
     }
 
 
@@ -1378,13 +1442,19 @@ class Notification
             "app_title"    => Misc::getToolCaption(),
             "user"         => $info
         ));
+
+        // change the current locale
+        Language::set(User::getLang($usr_id));
+
         $text_message = $tpl->getTemplateContents();
 
         // send email (use PEAR's classes)
         $mail = new Mail_API;
         $mail->setTextBody($text_message);
         $setup = $mail->getSMTPSettings();
-        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": New User information");
+        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": " . ev_gettext("New User information"));
+
+        Language::restore();
     }
 
 
@@ -1412,18 +1482,23 @@ class Notification
                 "issue"        => $issue,
                 "data"         => $data
             ));
-            $text_message = $tpl->getTemplateContents();
 
             for ($i = 0; $i < count($assignees); $i++) {
                 if (!Workflow::shouldEmailAddress($prj_id, Mail_API::getEmailAddress(User::getFromHeader($assignees[$i])))) {
                     continue;
                 }
+
+                // change the current locale
+                Language::set(User::getLang($assignees[$i]));
+                $text_message = $tpl->getTemplateContents();
+
                 // send email (use PEAR's classes)
                 $mail = new Mail_API;
                 $mail->setTextBody($text_message);
                 $mail->setHeaders(Mail_API::getBaseThreadingHeaders($issue_id));
                 $mail->send(Notification::getFixedFromHeader($issue_id, '', 'issue'), User::getFromHeader($assignees[$i]), "[#$issue_id] $title: " . $issue['iss_summary'], TRUE, $issue_id, $type);
             }
+            Language::restore();
         }
 
     }
@@ -1461,15 +1536,18 @@ class Notification
             "issue"        => $issue,
             "current_user" => User::getFullName(Auth::getUserID())
         ));
-        $text_message = $tpl->getTemplateContents();
 
         for ($i = 0; $i < count($emails); $i++) {
+            $text_message = $tpl->getTemplateContents();
+            Language::set(User::getLang(User::getUserIDByEmail(Mail_API::getEmailAddress($emails[$i]))));
+
             // send email (use PEAR's classes)
             $mail = new Mail_API;
             $mail->setTextBody($text_message);
             $mail->setHeaders(Mail_API::getBaseThreadingHeaders($issue_id));
             $mail->send(Notification::getFixedFromHeader($issue_id, '', 'issue'), $emails[$i], "[#$issue_id] New Assignment: " . $issue['iss_summary'], TRUE, $issue_id, 'assignment');
         }
+        Language::restore();
     }
 
 
@@ -1491,13 +1569,16 @@ class Notification
             "app_title"    => Misc::getToolCaption(),
             "user"         => $info
         ));
+
+        Language::set(User::getLang($usr_id));
         $text_message = $tpl->getTemplateContents();
 
         // send email (use PEAR's classes)
         $mail = new Mail_API;
         $mail->setTextBody($text_message);
         $setup = $mail->getSMTPSettings();
-        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": Your User Account Details");
+        $mail->send($setup["from"], $mail->getFormattedName($info["usr_full_name"], $info["usr_email"]), APP_SHORT_NAME . ": " . ev_gettext("Your User Account Details"));
+        Language::restore();
     }
 
 
@@ -1520,27 +1601,42 @@ class Notification
         );
         $prj_id = Issue::getProjectID($issue_id);
         $stmt = "SELECT
-                    DISTINCT sub_usr_id,
+                    sub_usr_id,
                     usr_full_name,
+                    usr_email,
                     pru_role
                  FROM
+                    (
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription,
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription_type,
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user,
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_user
-                 WHERE
-                    sub_id = sbt_sub_id AND
-                    sub_usr_id=usr_id AND
-                    sub_usr_id = pru_usr_id AND
-                    pru_prj_id = $prj_id AND
-                    sub_iss_id=$issue_id";
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user";
+
         if ($type != false) {
-            $stmt .= " AND\nsbt_type = '" . Misc::escapeString($type) . "'";
+            $stmt .= ",
+                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription_type";
         }
+        $stmt .= "
+                    )
+                    LEFT JOIN
+                        " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_user
+                    ON
+                        (sub_usr_id = pru_usr_id AND pru_prj_id = $prj_id)
+                 WHERE
+                    sub_usr_id=usr_id AND
+                    sub_iss_id=$issue_id";
         if ($min_role != false) {
-            $stmt .= " AND\npru_role >= " . Misc::escapeInteger($min_role);
+            $stmt .= " AND
+                    pru_role >= " . Misc::escapeInteger($min_role);
+        }
+        if ($type != false) {
+            $stmt .= " AND\nsbt_sub_id = sub_id AND
+                      sbt_type = '" . Misc::escapeString($type) . "'";
         }
         $users = $GLOBALS["db_api"]->dbh->getAll($stmt, DB_FETCHMODE_ASSOC);
+        if (PEAR::isError($users)) {
+            Error_Handler::logError(array($users->getMessage(), $users->getDebugInfo()), __FILE__, __LINE__);
+            return array();
+        }
+
         for ($i = 0; $i < count($users); $i++) {
             if ($users[$i]['pru_role'] != User::getRoleID('Customer')) {
                 $subscribers['staff'][] = $users[$i]['usr_full_name'];
@@ -1575,6 +1671,10 @@ class Notification
                 $stmt .= " AND\nsbt_type = '" . Misc::escapeString($type) . "'";
             }
             $emails = $GLOBALS["db_api"]->dbh->getAll($stmt, DB_FETCHMODE_ASSOC);
+            if (PEAR::isError($emails)) {
+                Error_Handler::logError(array($emails->getMessage(), $emails->getDebugInfo()), __FILE__, __LINE__);
+                return array();
+            }
             for ($i = 0; $i < count($emails); $i++) {
                 if (empty($emails[$i]['sub_email'])) {
                     continue;
@@ -1749,7 +1849,7 @@ class Notification
             $GLOBALS["db_api"]->dbh->query($stmt);
             // need to save a history entry for this
             History::add($issue_id, Auth::getUserID(), History::getTypeID('notification_removed'),
-                            "Notification list entry ('$subscriber') removed by " . User::getFullName(Auth::getUserID()));
+                            ev_gettext('Notification list entry (%1$s) removed by %2$s', $subscriber, User::getFullName(Auth::getUserID())));
         }
         Issue::markAsUpdated($issue_id);
         return true;
@@ -1900,7 +2000,7 @@ class Notification
             // need to save a history entry for this
             if ($add_history) {
                 History::add($issue_id, $usr_id, History::getTypeID('notification_added'),
-                                "Notification list entry ('" . User::getFromHeader($subscriber_usr_id) . "') added by " . User::getFullName($usr_id));
+                                ev_gettext('Notification list entry (%1$s) added by %2$s', User::getFromHeader($subscriber_usr_id), User::getFullName($usr_id)));
             }
             return 1;
         }
@@ -1981,7 +2081,7 @@ class Notification
             Issue::markAsUpdated($issue_id);
             // need to save a history entry for this
             History::add($issue_id, $usr_id, History::getTypeID('notification_added'),
-                            "Notification list entry ('$email') added by " . User::getFullName($usr_id));
+                            ev_gettext('Notification list entry (\'%1$s\') added by %2$s', $email, User::getFullName($usr_id)));
             return 1;
         }
     }
@@ -2020,8 +2120,6 @@ class Notification
      */
     function update($sub_id)
     {
-        global $HTTP_POST_VARS;
-
         $sub_id = Misc::escapeInteger($sub_id);
 
         $stmt = "SELECT
@@ -2033,13 +2131,13 @@ class Notification
                     sub_id=$sub_id";
         list($issue_id, $usr_id) = $GLOBALS["db_api"]->dbh->getRow($stmt);
 
-        $email = strtolower(Mail_API::getEmailAddress($HTTP_POST_VARS["email"]));
+        $email = strtolower(Mail_API::getEmailAddress($_POST["email"]));
         $usr_id = User::getUserIDByEmail($email);
         if (!empty($usr_id)) {
             $email = '';
         } else {
             $usr_id = 0;
-            $email = Misc::escapeString($HTTP_POST_VARS["email"]);
+            $email = Misc::escapeString($_POST["email"]);
         }
         $prj_id = Issue::getProjectID($issue_id);
 
@@ -2072,14 +2170,14 @@ class Notification
                         sbt_sub_id=$sub_id";
             $GLOBALS["db_api"]->dbh->query($stmt);
             // now add them all again
-            for ($i = 0; $i < count($HTTP_POST_VARS["actions"]); $i++) {
-                Notification::addType($sub_id, $HTTP_POST_VARS["actions"][$i]);
+            for ($i = 0; $i < count($_POST["actions"]); $i++) {
+                Notification::addType($sub_id, $_POST["actions"][$i]);
             }
             // need to mark the issue as updated
             Issue::markAsUpdated($issue_id);
             // need to save a history entry for this
             History::add($issue_id, Auth::getUserID(), History::getTypeID('notification_updated'),
-                            "Notification list entry ('" . Notification::getSubscriber($sub_id) . "') updated by " . User::getFullName(Auth::getUserID()));
+                            ev_gettext('Notification list entry (\'%1$s\') updated by %2$s', Notification::getSubscriber($sub_id), User::getFullName(Auth::getUserID())));
             return 1;
         }
     }
@@ -2089,4 +2187,3 @@ class Notification
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Notification Class');
 }
-?>
\ No newline at end of file
