@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,19 +22,19 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.pager.php 1.7 03/12/31 17:29:01-00:00 jpradomaia $
+// @(#) $Id: class.pager.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
 
 /**
  * Class to manage paginated links on the frontend pages.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Pager
@@ -87,11 +87,9 @@ class Pager
      */
     function _buildQueryString()
     {
-        global $HTTP_GET_VARS;
-
         $query_str = "";
         // gotta check manually here
-        $params = $HTTP_GET_VARS;
+        $params = $_GET;
         while (list($key, $value) = each($params)) {
             if ($key != "pagerRow") {
                 $query_str .= "&" . $key . "=" . urlencode($value);
@@ -116,27 +114,18 @@ class Pager
      */
     function getLinks($row, $total_rows, $per_page, $show_links = "all", $show_blank = "off", $link_str = -1)
     {
-        global $HTTP_SERVER_VARS;
-
         // check for emptyness
         if ((empty($total_rows)) || (empty($per_page))) {
             return array();
         }
         if ($link_str == -1) {
-            if (APP_CURRENT_LANG == "br") {
-                $link_str = array(
-                    "previous" => "&lt;&lt; Anterior",
-                    "next"     => "Prxima &gt;&gt;"
-                );
-            } else {
-                $link_str = array(
-                    "previous" => "&lt;&lt; Previous",
-                    "next"     => "Next &gt;&gt;"
-                );
-            }
+            $link_str = array(
+                "previous" => "&lt;&lt; " . ev_gettext("Previous"),
+                "next"     => ev_gettext("Next") . " &gt;&gt;"
+            );
         }
         $extra_vars = Pager::_buildQueryString();
-        $file = $HTTP_SERVER_VARS["SCRIPT_NAME"];
+        $file = $_SERVER["SCRIPT_NAME"];
         $number_of_pages = ceil($total_rows / $per_page);
         $subscript = 0;
         for ($current = 0; $current < $number_of_pages; $current++) {
@@ -221,4 +210,3 @@ class Pager
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Pager Class');
 }
-?>
\ No newline at end of file
