@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,26 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.phone_support.php 1.6 03/12/31 17:29:01-00:00 jpradomaia $
+// @(#) $Id: class.phone_support.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.history.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.date.php");
 
 /**
  * Class to handle the business logic related to the phone support
  * feature of the application.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Phone_Support
@@ -54,9 +54,7 @@ class Phone_Support
      */
     function insertCategory()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "INSERT INTO
@@ -65,8 +63,8 @@ class Phone_Support
                     phc_prj_id,
                     phc_title
                  ) VALUES (
-                    " . Misc::escapeInteger($HTTP_POST_VARS["prj_id"]) . ",
-                    '" . Misc::escapeString($HTTP_POST_VARS["title"]) . "'
+                    " . Misc::escapeInteger($_POST["prj_id"]) . ",
+                    '" . Misc::escapeString($_POST["title"]) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -79,8 +77,8 @@ class Phone_Support
 
 
     /**
-     * Method used to update the values stored in the database. 
-     * Typically the user would modify the title of the category in 
+     * Method used to update the values stored in the database.
+     * Typically the user would modify the title of the category in
      * the application and this method would be called.
      *
      * @access  public
@@ -88,18 +86,16 @@ class Phone_Support
      */
     function updateCategory()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_phone_category
                  SET
-                    phc_title='" . Misc::escapeString($HTTP_POST_VARS["title"]) . "'
+                    phc_title='" . Misc::escapeString($_POST["title"]) . "'
                  WHERE
-                    phc_prj_id=" . Misc::escapeInteger($HTTP_POST_VARS["prj_id"]) . " AND
-                    phc_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                    phc_prj_id=" . Misc::escapeInteger($_POST["prj_id"]) . " AND
+                    phc_id=" . Misc::escapeInteger($_POST["id"]);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -111,7 +107,7 @@ class Phone_Support
 
 
     /**
-     * Method used to remove user-selected categories from the 
+     * Method used to remove user-selected categories from the
      * database.
      *
      * @access  public
@@ -119,9 +115,7 @@ class Phone_Support
      */
     function removeCategory()
     {
-        global $HTTP_POST_VARS;
-
-        $items = @implode(", ", Misc::escapeInteger($HTTP_POST_VARS["items"]));
+        $items = @implode(", ", Misc::escapeInteger($_POST["items"]));
         $stmt = "DELETE FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_phone_category
                  WHERE
@@ -191,7 +185,7 @@ class Phone_Support
 
 
     /**
-     * Method used to get an associative array of the list of 
+     * Method used to get an associative array of the list of
      * categories associated with a specific project.
      *
      * @access  public
@@ -245,7 +239,7 @@ class Phone_Support
 
 
     /**
-     * Method used to get the full listing of phone support entries 
+     * Method used to get the full listing of phone support entries
      * associated with a specific issue.
      *
      * @access  public
@@ -288,7 +282,7 @@ class Phone_Support
 
 
     /**
-     * Method used to add a phone support entry using the user 
+     * Method used to add a phone support entry using the user
      * interface form available in the application.
      *
      * @access  public
@@ -296,14 +290,12 @@ class Phone_Support
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
         $usr_id = Auth::getUserID();
         // format the date from the form
-        $created_date = sprintf('%04d-%02d-%02d %02d:%02d:%02d', 
-            $HTTP_POST_VARS["date"]["Year"], $HTTP_POST_VARS["date"]["Month"],
-            $HTTP_POST_VARS["date"]["Day"], $HTTP_POST_VARS["date"]["Hour"],
-            $HTTP_POST_VARS["date"]["Minute"], 0);
+        $created_date = sprintf('%04d-%02d-%02d %02d:%02d:%02d',
+            $_POST["date"]["Year"], $_POST["date"]["Month"],
+            $_POST["date"]["Day"], $_POST["date"]["Hour"],
+            $_POST["date"]["Minute"], 0);
         // convert the date to GMT timezone
         $created_date = Date_API::getDateGMT($created_date);
         $stmt = "INSERT INTO
@@ -322,18 +314,18 @@ class Phone_Support
                     phs_call_to_lname,
                     phs_call_to_fname
                  ) VALUES (
-                    " . Misc::escapeInteger($HTTP_POST_VARS["issue_id"]) . ",
+                    " . Misc::escapeInteger($_POST["issue_id"]) . ",
                     $usr_id,
-                    " . Misc::escapeInteger($HTTP_POST_VARS["phone_category"]) . ",
+                    " . Misc::escapeInteger($_POST["phone_category"]) . ",
                     '" . Misc::escapeString($created_date) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["type"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["phone_number"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["description"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["phone_type"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["from_lname"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["from_fname"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["to_lname"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["to_fname"]) . "'
+                    '" . Misc::escapeString($_POST["type"]) . "',
+                    '" . Misc::escapeString($_POST["phone_number"]) . "',
+                    '" . Misc::escapeString($_POST["description"]) . "',
+                    '" . Misc::escapeString($_POST["phone_type"]) . "',
+                    '" . Misc::escapeString($_POST["from_lname"]) . "',
+                    '" . Misc::escapeString($_POST["from_fname"]) . "',
+                    '" . Misc::escapeString($_POST["to_lname"]) . "',
+                    '" . Misc::escapeString($_POST["to_fname"]) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -342,25 +334,25 @@ class Phone_Support
         } else {
             // enter the time tracking entry about this phone support entry
             $phs_id = $GLOBALS["db_api"]->get_last_insert_id();
-            $HTTP_POST_VARS['category'] = Time_Tracking::getCategoryID('Telephone Discussion');
-            $HTTP_POST_VARS['time_spent'] = $HTTP_POST_VARS['call_length'];
-            $HTTP_POST_VARS['summary'] = 'Time entry inserted from phone call.';
+            $_POST['category'] = Time_Tracking::getCategoryID('Telephone Discussion');
+            $_POST['time_spent'] = $_POST['call_length'];
+            $_POST['summary'] = ev_gettext("Time entry inserted from phone call.");
             Time_Tracking::insertEntry();
             $stmt = "SELECT
                         max(ttr_id)
                      FROM
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "time_tracking
                      WHERE
-                        ttr_iss_id = " . Misc::escapeInteger($HTTP_POST_VARS["issue_id"]) . " AND
+                        ttr_iss_id = " . Misc::escapeInteger($_POST["issue_id"]) . " AND
                         ttr_usr_id = $usr_id";
             $ttr_id = $GLOBALS["db_api"]->dbh->getOne($stmt);
-            
-            Issue::markAsUpdated($HTTP_POST_VARS['issue_id'], 'phone call');
+
+            Issue::markAsUpdated($_POST['issue_id'], 'phone call');
             // need to save a history entry for this
-            History::add($HTTP_POST_VARS['issue_id'], $usr_id, History::getTypeID('phone_entry_added'), 
-                            'Phone Support entry submitted by ' . User::getFullName($usr_id));
+            History::add($_POST['issue_id'], $usr_id, History::getTypeID('phone_entry_added'),
+                            ev_gettext('Phone Support entry submitted by %1$s', User::getFullName($usr_id)));
             // XXX: send notifications for the issue being updated (new notification type phone_support?)
-            
+
             // update phone record with time tracking ID.
             if ((!empty($phs_id)) && (!empty($ttr_id))) {
                 $stmt = "UPDATE
@@ -381,7 +373,7 @@ class Phone_Support
 
 
     /**
-     * Method used to remove a specific phone support entry from the 
+     * Method used to remove a specific phone support entry from the
      * application.
      *
      * @access  public
@@ -391,7 +383,7 @@ class Phone_Support
     function remove($phone_id)
     {
         $phone_id = Misc::escapeInteger($phone_id);
-        
+
         $stmt = "SELECT
                     phs_iss_id,
                     phs_ttr_id,
@@ -416,9 +408,9 @@ class Phone_Support
         } else {
             Issue::markAsUpdated($details["phs_iss_id"]);
             // need to save a history entry for this
-            History::add($details["phs_iss_id"], Auth::getUserID(), History::getTypeID('phone_entry_removed'), 
-                            'Phone Support entry removed by ' . User::getFullName(Auth::getUserID()));
-            
+            History::add($details["phs_iss_id"], Auth::getUserID(), History::getTypeID('phone_entry_removed'),
+                            ev_gettext('Phone Support entry removed by %1$s', User::getFullName(Auth::getUserID())));
+
             if (!empty($details["phs_ttr_id"])) {
                 $time_result = Time_Tracking::removeEntry($details["phs_ttr_id"], $details['phs_usr_id']);
                 if ($time_result == 1) {
@@ -460,7 +452,7 @@ class Phone_Support
 
     /**
      * Returns the number of calls by a user in a time range.
-     * 
+     *
      * @access  public
      * @param   string $usr_id The ID of the user
      * @param   integer $start The timestamp of the start date
@@ -472,8 +464,11 @@ class Phone_Support
         $stmt = "SELECT
                     COUNT(phs_id)
                  FROM
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "phone_support
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "phone_support,
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
                  WHERE
+                    phs_iss_id = iss_id AND
+                    iss_prj_id = " . Auth::getCurrentProject() . " AND
                     phs_created_date BETWEEN '" . Misc::escapeString($start) . "' AND '" . Misc::escapeString($end) . "' AND
                     phs_usr_id = " . Misc::escapeInteger($usr_id);
         $res = $GLOBALS["db_api"]->dbh->getOne($stmt);
@@ -489,4 +484,3 @@ class Phone_Support
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Phone_Support Class');
 }
-?>
\ No newline at end of file
