@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,31 +22,31 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.project.php 1.36 04/01/07 20:59:37-00:00 jpradomaia $
+// @(#) $Id: class.project.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.group.php");
-include_once(APP_INC_PATH . "class.validation.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.category.php");
-include_once(APP_INC_PATH . "class.release.php");
-include_once(APP_INC_PATH . "class.filter.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.display_column.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.group.php");
+require_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.category.php");
+require_once(APP_INC_PATH . "class.release.php");
+require_once(APP_INC_PATH . "class.filter.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.display_column.php");
 
 /**
  * Class to handle the business logic related to the administration
  * of projects in the system.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Project
@@ -155,13 +155,11 @@ class Project
      */
     function updateAnonymousPost($prj_id)
     {
-        global $HTTP_POST_VARS;
-
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project
                  SET
-                    prj_anonymous_post='" . Misc::escapeString($HTTP_POST_VARS["anonymous_post"]) . "',
-                    prj_anonymous_post_options='" . Misc::escapeString(@serialize($HTTP_POST_VARS["options"])) . "'
+                    prj_anonymous_post='" . Misc::escapeString($_POST["anonymous_post"]) . "',
+                    prj_anonymous_post_options='" . Misc::escapeString(@serialize($_POST["options"])) . "'
                  WHERE
                     prj_id=" . Misc::escapeInteger($prj_id);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -360,9 +358,7 @@ class Project
      */
     function remove()
     {
-        global $HTTP_POST_VARS;
-
-        $items = @implode(", ", Misc::escapeInteger($HTTP_POST_VARS["items"]));
+        $items = @implode(", ", Misc::escapeInteger($_POST["items"]));
         $stmt = "DELETE FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project
                  WHERE
@@ -372,18 +368,18 @@ class Project
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return false;
         } else {
-            Project::removeUserByProjects($HTTP_POST_VARS["items"]);
-            Category::removeByProjects($HTTP_POST_VARS["items"]);
-            Release::removeByProjects($HTTP_POST_VARS["items"]);
-            Filter::removeByProjects($HTTP_POST_VARS["items"]);
-            Email_Account::removeAccountByProjects($HTTP_POST_VARS["items"]);
-            Issue::removeByProjects($HTTP_POST_VARS["items"]);
-            Custom_Field::removeByProjects($HTTP_POST_VARS["items"]);
-            $statuses = array_keys(Status::getAssocStatusList($HTTP_POST_VARS["items"]));
-            foreach ($HTTP_POST_VARS["items"] as $prj_id) {
+            Project::removeUserByProjects($_POST["items"]);
+            Category::removeByProjects($_POST["items"]);
+            Release::removeByProjects($_POST["items"]);
+            Filter::removeByProjects($_POST["items"]);
+            Email_Account::removeAccountByProjects($_POST["items"]);
+            Issue::removeByProjects($_POST["items"]);
+            Custom_Field::removeByProjects($_POST["items"]);
+            $statuses = array_keys(Status::getAssocStatusList($_POST["items"]));
+            foreach ($_POST["items"] as $prj_id) {
                 Status::removeProjectAssociations($statuses, $prj_id);
             }
-            Group::disassociateProjects($HTTP_POST_VARS["items"]);
+            Group::disassociateProjects($_POST["items"]);
             return true;
         }
     }
@@ -426,46 +422,44 @@ class Project
      */
     function update()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project
                  SET
-                    prj_title='" . Misc::escapeString($HTTP_POST_VARS["title"]) . "',
-                    prj_status='" . Misc::escapeString($HTTP_POST_VARS["status"]) . "',
-                    prj_lead_usr_id=" . Misc::escapeInteger($HTTP_POST_VARS["lead_usr_id"]) . ",
-                    prj_initial_sta_id=" . Misc::escapeInteger($HTTP_POST_VARS["initial_status"]) . ",
-                    prj_outgoing_sender_name='" . Misc::escapeString($HTTP_POST_VARS["outgoing_sender_name"]) . "',
-                    prj_outgoing_sender_email='" . Misc::escapeString($HTTP_POST_VARS["outgoing_sender_email"]) . "',
-                    prj_remote_invocation='" . Misc::escapeString($HTTP_POST_VARS["remote_invocation"]) . "',
-                    prj_segregate_reporter='" . Misc::escapeString($HTTP_POST_VARS["segregate_reporter"]) . "',
-                    prj_customer_backend='" . Misc::escapeString($HTTP_POST_VARS["customer_backend"]) . "',
-                    prj_workflow_backend='" . Misc::escapeString($HTTP_POST_VARS["workflow_backend"]) . "'
+                    prj_title='" . Misc::escapeString($_POST["title"]) . "',
+                    prj_status='" . Misc::escapeString($_POST["status"]) . "',
+                    prj_lead_usr_id=" . Misc::escapeInteger($_POST["lead_usr_id"]) . ",
+                    prj_initial_sta_id=" . Misc::escapeInteger($_POST["initial_status"]) . ",
+                    prj_outgoing_sender_name='" . Misc::escapeString($_POST["outgoing_sender_name"]) . "',
+                    prj_outgoing_sender_email='" . Misc::escapeString($_POST["outgoing_sender_email"]) . "',
+                    prj_remote_invocation='" . Misc::escapeString($_POST["remote_invocation"]) . "',
+                    prj_segregate_reporter='" . Misc::escapeString($_POST["segregate_reporter"]) . "',
+                    prj_customer_backend='" . Misc::escapeString($_POST["customer_backend"]) . "',
+                    prj_workflow_backend='" . Misc::escapeString($_POST["workflow_backend"]) . "'
                  WHERE
-                    prj_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                    prj_id=" . Misc::escapeInteger($_POST["id"]);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return -1;
         } else {
-            Project::removeUserByProjects(array($HTTP_POST_VARS["id"]), $HTTP_POST_VARS["users"]);
-            for ($i = 0; $i < count($HTTP_POST_VARS["users"]); $i++) {
-                if ($HTTP_POST_VARS["users"][$i] == $HTTP_POST_VARS["lead_usr_id"]) {
-                    Project::associateUser($HTTP_POST_VARS["id"], $HTTP_POST_VARS["users"][$i], User::getRoleID("Manager"));
-                } elseif (User::getRoleByUser($HTTP_POST_VARS["users"][$i], $HTTP_POST_VARS["id"]) == '') {
+            Project::removeUserByProjects(array($_POST["id"]), $_POST["users"]);
+            for ($i = 0; $i < count($_POST["users"]); $i++) {
+                if ($_POST["users"][$i] == $_POST["lead_usr_id"]) {
+                    Project::associateUser($_POST["id"], $_POST["users"][$i], User::getRoleID("Manager"));
+                } elseif (User::getRoleByUser($_POST["users"][$i], $_POST["id"]) == '') {
                     // users who are now being associated with this project should be set to 'Standard User'
-                    Project::associateUser($HTTP_POST_VARS["id"], $HTTP_POST_VARS["users"][$i], User::getRoleID("Standard User"));
+                    Project::associateUser($_POST["id"], $_POST["users"][$i], User::getRoleID("Standard User"));
                 }
             }
-            $statuses = array_keys(Status::getAssocStatusList($HTTP_POST_VARS["id"]));
+            $statuses = array_keys(Status::getAssocStatusList($_POST["id"]));
             if (count($statuses) > 0) {
-                Status::removeProjectAssociations($statuses, $HTTP_POST_VARS["id"]);
+                Status::removeProjectAssociations($statuses, $_POST["id"]);
             }
-            foreach ($HTTP_POST_VARS['statuses'] as $sta_id) {
-                Status::addProjectAssociation($sta_id, $HTTP_POST_VARS["id"]);
+            foreach ($_POST['statuses'] as $sta_id) {
+                Status::addProjectAssociation($sta_id, $_POST["id"]);
             }
             return 1;
         }
@@ -532,9 +526,7 @@ class Project
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "INSERT INTO
@@ -552,15 +544,15 @@ class Project
                     prj_workflow_backend
                  ) VALUES (
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["title"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["status"]) . "',
-                    " . Misc::escapeInteger($HTTP_POST_VARS["lead_usr_id"]) . ",
-                    " . Misc::escapeInteger($HTTP_POST_VARS["initial_status"]) . ",
-                    '" . Misc::escapeString($HTTP_POST_VARS["outgoing_sender_name"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["outgoing_sender_email"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["remote_invocation"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["customer_backend"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["workflow_backend"]) . "'
+                    '" . Misc::escapeString($_POST["title"]) . "',
+                    '" . Misc::escapeString($_POST["status"]) . "',
+                    " . Misc::escapeInteger($_POST["lead_usr_id"]) . ",
+                    " . Misc::escapeInteger($_POST["initial_status"]) . ",
+                    '" . Misc::escapeString($_POST["outgoing_sender_name"]) . "',
+                    '" . Misc::escapeString($_POST["outgoing_sender_email"]) . "',
+                    '" . Misc::escapeString($_POST["remote_invocation"]) . "',
+                    '" . Misc::escapeString($_POST["customer_backend"]) . "',
+                    '" . Misc::escapeString($_POST["workflow_backend"]) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -568,26 +560,26 @@ class Project
             return -1;
         } else {
             $new_prj_id = $GLOBALS["db_api"]->get_last_insert_id();
-            for ($i = 0; $i < count($HTTP_POST_VARS["users"]); $i++) {
-                if ($HTTP_POST_VARS["users"][$i] == $HTTP_POST_VARS["lead_usr_id"]) {
+            for ($i = 0; $i < count($_POST["users"]); $i++) {
+                if ($_POST["users"][$i] == $_POST["lead_usr_id"]) {
                     $role_id = User::getRoleID("Manager");
                 } else {
                     $role_id = User::getRoleID("Standard User");
                 }
-                Project::associateUser($new_prj_id, $HTTP_POST_VARS["users"][$i], $role_id);
+                Project::associateUser($new_prj_id, $_POST["users"][$i], $role_id);
             }
-            foreach ($HTTP_POST_VARS['statuses'] as $sta_id) {
+            foreach ($_POST['statuses'] as $sta_id) {
                 Status::addProjectAssociation($sta_id, $new_prj_id);
             }
             Display_Column::setupNewProject($new_prj_id);
-            
+
             return 1;
         }
     }
 
 
     /**
-     * Method used to get the list of projects available in the 
+     * Method used to get the list of projects available in the
      * system.
      *
      * @access  public
@@ -772,7 +764,7 @@ class Project
 
 
     /**
-     * Method used to get a list of emails that are associated with a given 
+     * Method used to get a list of emails that are associated with a given
      * project and issue.
      *
      * @access  public
@@ -792,7 +784,7 @@ class Project
 
 
     /**
-     * Method used to get a list of names and emails that are 
+     * Method used to get a list of names and emails that are
      * associated with a given project and issue.
      *
      * @access  public
@@ -824,7 +816,7 @@ class Project
 
 
     /**
-     * Method used to get an associative array of names and emails 
+     * Method used to get an associative array of names and emails
      * that are associated with a given project and issue.
      *
      * @access  public
@@ -869,7 +861,7 @@ class Project
 
 
     /**
-     * Method used to get the list of projects that allow remote 
+     * Method used to get the list of projects that allow remote
      * invocation of issues.
      *
      * @access  public
@@ -897,7 +889,7 @@ class Project
 
 
     /**
-     * Method used to get the list of projects assigned to a given user that 
+     * Method used to get the list of projects assigned to a given user that
      * allow remote invocation of issues.
      *
      * @access  public
@@ -1025,7 +1017,7 @@ class Project
 
     /**
      * Sets the minimum role needed to view a specific field on the issue creation form.
-     * 
+     *
      * @access  public
      * @param   integer $prj_id The project ID.
      * @param   array $settings An array of fields and role is required to view them.
@@ -1043,7 +1035,7 @@ class Project
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return -1;
         }
-        
+
         // insert new values
         foreach ($settings as $field => $min_role) {
             $stmt = "INSERT INTO
@@ -1069,7 +1061,7 @@ class Project
 
     /**
      * Returns display settings for a specific project.
-     * 
+     *
      * @access public
      * @param   integer $prj_id The project ID
      * @return  array An associative array of minimum role required to access a field.
@@ -1100,21 +1092,21 @@ class Project
 
     /**
      * Returns an array of fields which can be hidden.
-     * 
+     *
      * @access  public
      * @return  array
      */
     function getDisplayFields()
     {
         return array(
-            "category"  =>  "Category",
-            "priority"  =>  "Priority",
-            "assignment"    =>  "Assignment",
-            "release"   =>  "Scheduled Release",
-            "estimated_dev_time"    =>  "Estimated Dev. Time",
-            "group"     =>  "Group",
-            "file"  =>  "File",
-            "private"   =>  "Private"
+            "category"  =>  ev_gettext("Category"),
+            "priority"  =>  ev_gettext("Priority"),
+            "assignment"    =>  ev_gettext("Assignment"),
+            "release"   =>  ev_gettext("Scheduled Release"),
+            "estimated_dev_time"    =>  ev_gettext("Estimated Dev. Time"),
+            "group"     =>  ev_gettext("Group"),
+            "file"  =>  ev_gettext("File"),
+            "private"   =>  ev_gettext("Private")
         );
     }
 }
@@ -1123,4 +1115,3 @@ class Project
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Project Class');
 }
-?>
\ No newline at end of file
