@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,28 +22,28 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.report.php 1.10 04/01/26 20:37:04-06:00 joao@kickass. $
+// @(#) $Id: class.report.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.history.php");
-include_once(APP_INC_PATH . "class.phone_support.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_PEAR_PATH . "Math/Stats.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.phone_support.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_PEAR_PATH . "Math/Stats.php");
 
 /**
  * Class to handle the business logic related to all aspects of the
  * reporting system.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Report
@@ -144,22 +144,24 @@ class Report
     }
 
     /**
-     * Method used to get all open issues and group them by user.
+     * Method used to get all open issues and group them by assignee or reporter.
      *
      * @access  public
      * @param   integer $prj_id The project ID
      * @param   integer $cutoff_days The number of days to use as a cutoff period
      * @return  array The list of issues
      */
-    function getOpenIssuesByUser($prj_id, $cutoff_days)
+    function getOpenIssuesByUser($prj_id, $cutoff_days, $group_by_reporter = false)
     {
         $prj_id = Misc::escapeInteger($prj_id);
         $cutoff_days = Misc::escapeInteger($cutoff_days);
         $ts = Date_API::getCurrentUnixTimestampGMT();
-        $cutoff_ts = $ts - ($cutoff_days * DAY);
+        $ts_diff = $cutoff_days * DAY;
+
 
         $stmt = "SELECT
-                    usr_full_name,
+                    assignee.usr_full_name as assignee_name,
+                    reporter.usr_full_name as reporter_name,
                     iss_id,
                     iss_summary,
                     sta_title,
@@ -172,7 +174,8 @@ class Report
                     (
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue,
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_user,
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user as assignee,
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user as reporter
                     )
                  LEFT JOIN
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "status
@@ -182,12 +185,18 @@ class Report
                     sta_is_closed=0 AND
                     iss_prj_id=$prj_id AND
                     iss_id=isu_iss_id AND
-                    isu_usr_id=usr_id AND
-                    UNIX_TIMESTAMP(iss_created_date) < $cutoff_ts
-                 ORDER BY
-                    usr_full_name";
+                    isu_usr_id=assignee.usr_id AND
+                    iss_usr_id=reporter.usr_id AND
+                    UNIX_TIMESTAMP(iss_created_date) < (UNIX_TIMESTAMP() - $ts_diff)
+                 ORDER BY\n";
+        if ($group_by_reporter) {
+            $stmt .= "reporter.usr_full_name";
+        } else {
+            $stmt .= "assignee.usr_full_name";
+        }
         $res = $GLOBALS["db_api"]->dbh->getAll($stmt, DB_FETCHMODE_ASSOC);
         if (PEAR::isError($res)) {
+            print_r($res);
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return "";
         } else {
@@ -200,7 +209,12 @@ class Report
                 if (empty($res[$i]['iss_last_response_date'])) {
                     $res[$i]['iss_last_response_date'] = $res[$i]['iss_created_date'];
                 }
-                $issues[$res[$i]['usr_full_name']][$res[$i]['iss_id']] = array(
+                if ($group_by_reporter) {
+                    $name = $res[$i]['reporter_name'];
+                } else {
+                    $name = $res[$i]['assignee_name'];
+                }
+                $issues[$name][$res[$i]['iss_id']] = array(
                     'iss_summary'         => $res[$i]['iss_summary'],
                     'sta_title'           => $res[$i]['sta_title'],
                     'iss_created_date'    => Date_API::getFormattedDate($res[$i]['iss_created_date']),
@@ -278,10 +292,12 @@ class Report
      * @param   string The start date of this report.
      * @param   string The end date of this report.
      * @param   boolean If closed issues should be separated from other issues.
+     * @param   boolean If issue status changes should be ignored in report.
      * @return  array An array of data containing all the elements of the weekly report.
      */
-    function getWeeklyReport($usr_id, $start, $end, $separate_closed = false)
+    function getWeeklyReport($usr_id, $start, $end, $separate_closed = false, $ignore_statuses = false)
     {
+        $prj_id = Auth::getCurrentProject();
         $usr_id = Misc::escapeInteger($usr_id);
 
         // figure out timezone
@@ -326,6 +342,7 @@ class Report
                     iss_id = isu_iss_id AND
                     iss_sta_id = sta_id AND
                     isu_usr_id = $usr_id AND
+                    iss_prj_id = " . Auth::getCurrentProject() . " AND
                     isu_assigned_date BETWEEN '$start_ts' AND '$end_ts'";
         $newly_assigned = $GLOBALS["db_api"]->dbh->getOne($stmt);
         if (PEAR::isError($newly_assigned)) {
@@ -337,12 +354,19 @@ class Report
             "other"         =>  Support::getSentEmailCountByUser($usr_id, $start_ts, $end_ts, false)
         );
 
+        $htt_exclude = array();
+        if ($ignore_statuses) {
+            $htt_exclude[] = 'status_changed';
+            $htt_exclude[] = 'status_auto_changed';
+            $htt_exclude[] = 'remote_status_change';
+        }
+
         $data = array(
             "start"     => str_replace('-', '.', $start),
             "end"       => str_replace('-', '.', $end),
             "user"      => User::getDetails($usr_id),
             "group_name"=> Group::getName(User::getGroupID($usr_id)),
-            "issues"    => History::getTouchedIssuesByUser($usr_id, $start_ts, $end_ts, $separate_closed),
+            "issues"    => History::getTouchedIssuesByUser($usr_id, $start_ts, $end_ts, $separate_closed, $htt_exclude),
             "status_counts" => History::getTouchedIssueCountByStatus($usr_id, $start_ts, $end_ts),
             "new_assigned_count"    =>  $newly_assigned,
             "time_tracking" => $time_tracking,
@@ -627,7 +651,8 @@ class Report
             }
             $sql .= APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field,
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
-                    WHERE\n";
+                    WHERE
+                        iss_prj_id = $prj_id AND\n";
             if (!is_object($backend)) {
                 $sql .= "cfo_id = icf_value AND";
             }
@@ -668,7 +693,8 @@ class Report
             }
             $stmt .= APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue_custom_field,
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
-                    WHERE\n";
+                    WHERE
+                        iss_prj_id = $prj_id AND\n";
             if (!is_object($backend)) {
                 $stmt .= "cfo_id = icf_value AND";
             }
@@ -851,4 +877,3 @@ class Report
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Report Class');
 }
-?>
\ No newline at end of file
