@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -26,19 +26,19 @@
 // +----------------------------------------------------------------------+
 //
 
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.mail.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.mime_helper.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.note.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.mail.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.mime_helper.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.note.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.history.php");
 
 /**
  * Class to handle all routing functionality
@@ -52,97 +52,74 @@ class Routing
      * Routes an email to the correct issue.
      *
      * @param   string $full_message The full email message, including headers
-     * @param   integer $email_account_id The ID of the email account this email should be routed too. If empty this method will try to figure it out
+     * @return  mixed   true or array(ERROR_CODE, ERROR_STRING) in case of failure
      */
-    function route_emails($full_message, $email_account_id = 0)
+    function route_emails($full_message)
     {
-        GLOBAL $HTTP_POST_VARS;
+        // need some validation here
+        if (empty($full_message)) {
+            return array(66, ev_gettext("Error: The email message was empty") . ".\n");
+        }
 
         // save the full message for logging purposes
         Support::saveRoutedEmail($full_message);
 
-        if (preg_match("/^(boundary=).*/m", $full_message)) {
-            $pattern = "/(Content-Type: multipart\/)(.+); ?\r?\n(boundary=)(.*)$/im";
-            $replacement = '$1$2; $3$4';
-            $full_message = preg_replace($pattern, $replacement, $full_message);
+        // check if the email routing interface is even supposed to be enabled
+        $setup = Setup::load();
+        if ($setup['email_routing']['status'] != 'enabled') {
+            return array(78, ev_gettext("Error: The email routing interface is disabled.") . "\n");
         }
+        if (empty($setup['email_routing']['address_prefix'])) {
+            return array(78, ev_gettext("Error: Please configure the email address prefix.") . "\n");
+        }
+        if (empty($setup['email_routing']['address_host'])) {
+            return array(78, ev_gettext("Error: Please configure the email address domain.") . "\n");
+        }
+
         // associate routed emails to the internal system account
         $sys_account = User::getNameEmail(APP_SYSTEM_USER_ID);
-        $associated_user = $sys_account['usr_email'];
-
-        // need some validation here
-        if (empty($full_message)) {
-            return array(66, "Error: The email message was empty.\n");
+        if (empty($sys_account['usr_email'])) {
+            return array(78, ev_gettext("Error: The associated user for the email routing interface needs to be set.") . "\n");
         }
-        if (empty($associated_user)) {
-            return array(78, "Error: The associated user for the email routing interface needs to be set.\n");
+        unset($sys_account);
+
+        // join the Content-Type line (for easier parsing?)
+        if (preg_match('/^boundary=/m', $full_message)) {
+            $pattern = "#(Content-Type: multipart/.+); ?\r?\n(boundary=.*)$#im";
+            $replacement = '$1; $2';
+            $full_message = preg_replace($pattern, $replacement, $full_message);
         }
 
-
-        //
-        // DON'T EDIT ANYTHING BELOW THIS LINE
-        //
-
         // remove the reply-to: header
-        if (preg_match("/^(reply-to:).*/im", $full_message)) {
+        if (preg_match('/^reply-to:.*/im', $full_message)) {
             $full_message = preg_replace("/^(reply-to:).*\n/im", '', $full_message, 1);
         }
 
-        // check for magic cookie
-        if (Mail_API::hasMagicCookie($full_message)) {
-            // strip the magic cookie
-            $full_message = Mail_API::stripMagicCookie($full_message);
-            $has_magic_cookie = true;
-        } else {
-            $has_magic_cookie = false;
-        }
-
         Auth::createFakeCookie(APP_SYSTEM_USER_ID);
 
-        // check if the email routing interface is even supposed to be enabled
-        $setup = Setup::load();
-        if ($setup['email_routing']['status'] != 'enabled') {
-            return array(78, "Error: The email routing interface is disabled.\n");
-        }
-        $prefix = $setup['email_routing']['address_prefix'];
-        // escape plus signs so 'issue+1@example.com' becomes a valid routing address
-        $prefix = str_replace('+', '\+', $prefix);
-        $mail_domain = quotemeta($setup['email_routing']['address_host']);
-        $mail_domain_alias = quotemeta(@$setup['email_routing']['host_alias']);
-        if (!empty($mail_domain_alias)) {
-            $mail_domain = "(?:" . $mail_domain . "|" . $mail_domain_alias . ")";
-        }
-        if (empty($prefix)) {
-            return array(78, "Error: Please configure the email address prefix.\n");
-        }
-        if (empty($mail_domain)) {
-            return array(78, "Error: Please configure the email address domain.\n");
-        }
         $structure = Mime_Helper::decode($full_message, true, true);
 
         // find which issue ID this email refers to
-        @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['to'], $matches);
-        @$issue_id = $matches[1];
-        // validation is always a good idea
-        if (empty($issue_id)) {
-            // we need to try the Cc header as well
-            @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['cc'], $matches);
-            if (!empty($matches[1])) {
-                $issue_id = $matches[1];
-            } else {
-                return array(65, "Error: The routed email had no associated Eventum issue ID or had an invalid recipient address.\n");
-            }
+        if (isset($structure->headers['to'])) {
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['to'], 'email');
         }
-        if (empty($email_account_id)) {
-            $issue_prj_id = Issue::getProjectID($issue_id);
-            if (empty($issue_prj_id)) {
-                return array(65, "Error: The routed email had no associated Eventum issue ID or had an invalid recipient address.\n");
-            }
-            $email_account_id = Email_Account::getEmailAccount($issue_prj_id);
+        // we need to try the Cc header as well
+        if (empty($issue_id) and isset($structure->headers['cc'])) {
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['cc'], 'email');
         }
 
+        if (empty($issue_id)) {
+            return array(65, ev_gettext("Error: The routed email had no associated Eventum issue ID or had an invalid recipient address.") . "\n");
+        }
+
+        $issue_prj_id = Issue::getProjectID($issue_id);
+        if (empty($issue_prj_id)) {
+            return array(65, ev_gettext("Error: The routed email had no associated Eventum issue ID or had an invalid recipient address.") . "\n");
+        }
+
+        $email_account_id = Email_Account::getEmailAccount($issue_prj_id);
         if (empty($email_account_id)) {
-            return array(78, "Error: Please provide the email account ID.\n");
+            return array(78, ev_gettext("Error: Please provide the email account ID.") . "\n");
         }
 
         $body = Mime_Helper::getMessageBody($structure);
@@ -168,14 +145,8 @@ class Routing
 
         $prj_id = Issue::getProjectID($issue_id);
         Auth::createFakeCookie(APP_SYSTEM_USER_ID, $prj_id);
-        $staff_emails = Project::getUserEmailAssocList($prj_id, 'active', User::getRoleID('Customer'));
-        $staff_emails = array_map('strtolower', $staff_emails);
-        // only allow staff users to use the magic cookie
-        if (!in_array($sender_email, array_values($staff_emails))) {
-            $has_magic_cookie = false;
-        }
 
-        if (Mime_Helper::hasAttachments($full_message)) {
+        if (Mime_Helper::hasAttachments($structure)) {
             $has_attachments = 1;
         } else {
             $has_attachments = 0;
@@ -222,7 +193,7 @@ class Routing
             $t['customer_id'] = "NULL";
         }
 
-        if ((!$has_magic_cookie) && (Support::blockEmailIfNeeded($t))) {
+        if (Support::blockEmailIfNeeded($t)) {
             return true;
         }
 
@@ -230,7 +201,7 @@ class Routing
         list($t['full_email'], $t['headers']) = Mail_API::rewriteThreadingHeaders($t['issue_id'], $t['full_email'], $t['headers'], "email");
         $res = Support::insertEmail($t, $structure, $sup_id);
         if ($res != -1) {
-            Support::extractAttachments($issue_id, $full_message);
+            Support::extractAttachments($issue_id, $structure);
 
             // notifications about new emails are always external
             $internal_only = false;
@@ -258,7 +229,7 @@ class Routing
                 }
             }
             // log routed email
-            History::add($issue_id, $usr_id, History::getTypeID('email_routed'), "Email routed from " . $structure->headers['from']);
+            History::add($issue_id, $usr_id, History::getTypeID('email_routed'), ev_gettext('Email routed from %1$s', $structure->headers['from']));
         }
 
         return true;
@@ -269,17 +240,17 @@ class Routing
      * Routes a note to the correct issue
      *
      * @param   string $full_message The full note
+     * @return  mixed   true or array(ERROR_CODE, ERROR_STRING) in case of failure
      */
     function route_notes($full_message)
     {
-        GLOBAL $HTTP_POST_VARS;
-
         // save the full message for logging purposes
         Note::saveRoutedNote($full_message);
 
-        if (preg_match("/^(boundary=).*/m", $full_message)) {
-            $pattern = "/(Content-Type: multipart\/)(.+); ?\r?\n(boundary=)(.*)$/im";
-            $replacement = '$1$2; $3$4';
+        // join the Content-Type line (for easier parsing?)
+        if (preg_match('/^boundary=/m', $full_message)) {
+            $pattern = "#(Content-Type: multipart/.+); ?\r?\n(boundary=.*)$#im";
+            $replacement = '$1; $2';
             $full_message = preg_replace($pattern, $replacement, $full_message);
         }
 
@@ -287,48 +258,39 @@ class Routing
 
         // need some validation here
         if (empty($full_message)) {
-            return array(66, "Error: The email message was empty.\n");
+            return array(66, ev_gettext("Error: The email message was empty.") . "\n");
         }
 
-
-        //
-        // DON'T EDIT ANYTHING BELOW THIS LINE
-        //
-
         // remove the reply-to: header
-        if (preg_match("/^(reply-to:).*/im", $full_message)) {
+        if (preg_match('/^reply-to:.*/im', $full_message)) {
             $full_message = preg_replace("/^(reply-to:).*\n/im", '', $full_message, 1);
         }
 
         // check if the email routing interface is even supposed to be enabled
         $setup = Setup::load();
         if (@$setup['note_routing']['status'] != 'enabled') {
-            return array(78, "Error: The internal note routing interface is disabled.\n");
+            return array(78, ev_gettext("Error: The internal note routing interface is disabled.") . "\n");
         }
-        $prefix = $setup['note_routing']['address_prefix'];
-        // escape plus signs so 'note+1@example.com' becomes a valid routing address
-        $prefix = str_replace('+', '\+', $prefix);
-        $mail_domain = quotemeta($setup['note_routing']['address_host']);
-        if (empty($prefix)) {
-            return array(78, "Error: Please configure the email address prefix.\n");
+        if (empty($setup['note_routing']['address_prefix'])) {
+            return array(78, ev_gettext("Error: Please configure the email address prefix.") . "\n");
         }
-        if (empty($mail_domain)) {
-            return array(78, "Error: Please configure the email address domain.\n");
+        if (empty($setup['note_routing']['address_host'])) {
+            return array(78, ev_gettext("Error: Please configure the email address domain.") . "\n");
         }
         $structure = Mime_Helper::decode($full_message, true, true);
 
         // find which issue ID this email refers to
-        @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['to'], $matches);
-        @$issue_id = $matches[1];
+        if (isset($structure->headers['to'])) {
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['to'], 'note');
+        }
         // validation is always a good idea
-        if (empty($issue_id)) {
+        if (empty($issue_id) and isset($structure->headers['cc'])) {
             // we need to try the Cc header as well
-            @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['cc'], $matches);
-            if (!empty($matches[1])) {
-                $issue_id = $matches[1];
-            } else {
-                return array(65, "Error: The routed note had no associated Eventum issue ID or had an invalid recipient address.\n");
-            }
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['cc'], 'note');
+        }
+
+        if (empty($issue_id)) {
+            return array(65, ev_gettext("Error: The routed note had no associated Eventum issue ID or had an invalid recipient address.") . "\n");
         }
 
         $prj_id = Issue::getProjectID($issue_id);
@@ -337,7 +299,7 @@ class Routing
         $sender_email = strtolower(Mail_API::getEmailAddress($structure->headers['from']));
         $user_emails = array_map('strtolower', array_values($users));
         if (!in_array($sender_email, $user_emails)) {
-            return array(77, "Error: The sender of this email is not allowed in the project associated with issue #$issue_id.\n");
+            return array(77, ev_gettext("Error: The sender of this email is not allowed in the project associated with issue #$issue_id.") . "\n");
         }
 
         Auth::createFakeCookie(User::getUserIDByEmail($sender_email), $prj_id);
@@ -356,12 +318,11 @@ class Routing
         $cc_users = array();
         foreach ($addresses as $email) {
             if (in_array(strtolower($email), $user_emails)) {
-                $cc_users[] = $users[$email];
+                $cc_users[] = $users[strtolower($email)];
             }
         }
 
         $body = Mime_Helper::getMessageBody($structure);
-
         $reference_msg_id = Mail_API::getReferenceMessageID($headers);
         if (!empty($reference_msg_id)) {
             $parent_id = Note::getIDByMessageID($reference_msg_id);
@@ -370,7 +331,7 @@ class Routing
         }
 
         // insert the new note and send notification about it
-        $HTTP_POST_VARS = array(
+        $_POST = array(
             'title'                => @$structure->headers['subject'],
             'note'                 => $body,
             'note_cc'              => $cc_users,
@@ -381,15 +342,16 @@ class Routing
 
         // add the full email to the note if there are any attachments
         // this is needed because the front end code will display attachment links
-        if (Mime_Helper::hasAttachments($full_message)) {
-            $HTTP_POST_VARS['blocked_msg'] = $full_message;
+        if (Mime_Helper::hasAttachments($structure)) {
+            $_POST['blocked_msg'] = $full_message;
         }
         $res = Note::insert(Auth::getUserID(), $issue_id, false, false);
         // need to handle attachments coming from notes as well
         if ($res != -1) {
-            Support::extractAttachments($issue_id, $full_message, true, $res);
+            Support::extractAttachments($issue_id, $structure, true, $res);
         }
-        History::add($issue_id, Auth::getUserID(), History::getTypeID('note_routed'), "Note routed from " . $structure->headers['from']);
+        // FIXME! $res == -2 is not handled
+        History::add($issue_id, Auth::getUserID(), History::getTypeID('note_routed'), ev_gettext('Note routed from %1$s', $structure->headers['from']));
 
         return true;
     }
@@ -399,11 +361,10 @@ class Routing
      * Routes a draft to the correct issue.
      *
      * @param   string $full_message The complete draft.
+     * @return  mixed   true or array(ERROR_CODE, ERROR_STRING) in case of failure
      */
     function route_drafts($full_message)
     {
-        GLOBAL $HTTP_POST_VARS;
-
         // save the full message for logging purposes
         Draft::saveRoutedMessage($full_message);
 
@@ -415,14 +376,9 @@ class Routing
 
         // need some validation here
         if (empty($full_message)) {
-            return array(66, "Error: The email message was empty.\n");
+            return array(66, ev_gettext("Error: The email message was empty.") . "\n");
         }
 
-
-        //
-        // DON'T EDIT ANYTHING BELOW THIS LINE
-        //
-
         // remove the reply-to: header
         if (preg_match("/^(reply-to:).*/im", $full_message)) {
             $full_message = preg_replace("/^(reply-to:).*\n/im", '', $full_message, 1);
@@ -431,32 +387,29 @@ class Routing
         // check if the draft interface is even supposed to be enabled
         $setup = Setup::load();
         if (@$setup['draft_routing']['status'] != 'enabled') {
-            return array(78, "Error: The email draft interface is disabled.\n");
+            return array(78, ev_gettext("Error: The email draft interface is disabled.") . "\n");
         }
-        $prefix = $setup['draft_routing']['address_prefix'];
-        // escape plus signs so 'draft+1@example.com' becomes a valid address
-        $prefix = str_replace('+', '\+', $prefix);
-        $mail_domain = quotemeta($setup['draft_routing']['address_host']);
-        if (empty($prefix)) {
-            return array(78, "Error: Please configure the email address prefix.\n");
+        if (empty($setup['draft_routing']['address_prefix'])) {
+            return array(78, ev_gettext("Error: Please configure the email address prefix.") . "\n");
         }
-        if (empty($mail_domain)) {
-            return array(78, "Error: Please configure the email address domain.\n");
+        if (empty($setup['draft_routing']['address_host'])) {
+            return array(78, ev_gettext("Error: Please configure the email address domain.") . "\n");
         }
+
         $structure = Mime_Helper::decode($full_message, true, false);
 
         // find which issue ID this email refers to
-        @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['to'], $matches);
-        @$issue_id = $matches[1];
+        if (isset($structure->headers['to'])) {
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['to'], 'draft');
+        }
         // validation is always a good idea
-        if (empty($issue_id)) {
+        if (empty($issue_id) and isset($structure->headers['cc'])) {
             // we need to try the Cc header as well
-            @preg_match("/$prefix(\d*)@$mail_domain/i", $structure->headers['cc'], $matches);
-            if (!empty($matches[1])) {
-                $issue_id = $matches[1];
-            } else {
-                return array(65, "Error: The routed draft had no associated Eventum issue ID or had an invalid recipient address.\n");
-            }
+            $issue_id = Routing::getMatchingIssueIDs($structure->headers['cc'], 'draft');
+        }
+
+        if (empty($issue_id)) {
+            return array(65, ev_gettext("Error: The routed email had no associated Eventum issue ID or had an invalid recipient address.") . "\n");
         }
 
         $prj_id = Issue::getProjectID($issue_id);
@@ -465,7 +418,7 @@ class Routing
         $sender_email = strtolower(Mail_API::getEmailAddress($structure->headers['from']));
         $user_emails = array_map('strtolower', array_values($users));
         if (!in_array($sender_email, $user_emails)) {
-            return array(77, "Error: The sender of this email is not allowed in the project associated with issue #$issue_id.\n");
+            return array(77, ev_gettext("Error: The sender of this email is not allowed in the project associated with issue #") . "$issue_id.\n");
         }
 
         Auth::createFakeCookie(User::getUserIDByEmail($sender_email), $prj_id);
@@ -474,8 +427,56 @@ class Routing
 
         Draft::saveEmail($issue_id, @$structure->headers['to'], @$structure->headers['cc'], @$structure->headers['subject'], $body, false, false, false);
         // XXX: need to handle attachments coming from drafts as well?
-        History::add($issue_id, Auth::getUserID(), History::getTypeID('draft_routed'), "Draft routed from " . $structure->headers['from']);
+        History::add($issue_id, Auth::getUserID(), History::getTypeID('draft_routed'), ev_gettext("Draft routed from") . " " . $structure->headers['from']);
         return true;
     }
+
+    /**
+     * Check for $adresses for matches
+     *
+     * @param   mixed   $addresses to check
+     * @param   string  Type of address match to find (email, note, draft)
+     * @return  mixed   $issue_id in case of match otherwise false
+     */
+    function getMatchingIssueIDs($addresses, $type)
+    {
+        $setup = Setup::load();
+        $settings = $setup["${type}_routing"];
+        if (!is_array($settings)) {
+            return false;
+        }
+
+        if (empty($settings['address_prefix'])) {
+            return false;
+        }
+        // escape plus signs so 'issue+1@example.com' becomes a valid routing address
+        $prefix = quotemeta($settings['address_prefix']);
+
+        if (empty($settings['address_host'])) {
+            return false;
+        }
+        $mail_domain = quotemeta($settings['address_host']);
+
+        // it is not checked for type when host alias is asked. this leaves
+        // room foradding host_alias for other than email routing.
+        if (isset($settings['host_alias'])) {
+            // TODO: can't quotemeta() host alias as it can contain multiple hosts separated with pipe
+            $mail_domain = '(?:' . $mail_domain . '|' . $settings['host_alias'] . ')';
+        }
+
+        // if there are multiple CC or To headers Mail_Mime creates array.
+        // handle both cases (strings and arrays).
+        if (!is_array($addresses)) {
+            $addresses = array($addresses);
+        }
+
+        // everything safely escaped and checked, try matching address
+        foreach ($addresses as $address) {
+            if (preg_match("/$prefix(\d*)@$mail_domain/i", $address, $matches)) {
+                return $matches[1];
+            }
+        }
+
+        return false;
+    }
 }
-?>
