@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,23 +22,23 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.user.php 1.55 04/01/26 20:37:04-06:00 joao@kickass. $
+// @(#) $Id: class.user.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.mail.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "class.validation.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "private_key.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.mail.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_CONFIG_PATH . "private_key.php");
 
 // definition of roles
 $roles = array(
@@ -56,7 +56,7 @@ $roles = array(
  * of users and permissions in the system.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class User
@@ -298,10 +298,8 @@ class User
      */
     function createVisitorAccount($role, $projects)
     {
-        global $HTTP_POST_VARS;
-
         // check for double submits
-        if (Auth::userExists($HTTP_POST_VARS["email"])) {
+        if (Auth::userExists($_POST["email"])) {
             return -2;
         }
         $prefs = Prefs::getDefaults($projects);
@@ -316,9 +314,9 @@ class User
                     usr_status
                  ) VALUES (
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . Auth::hashPassword(Misc::escapeString($HTTP_POST_VARS["passwd"])) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["full_name"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["email"]) . "',
+                    '" . Auth::hashPassword(Misc::escapeString($_POST["passwd"])) . "',
+                    '" . Misc::escapeString($_POST["full_name"]) . "',
+                    '" . Misc::escapeString($_POST["email"]) . "',
                     '" . Misc::escapeString($prefs) . "',
                     'pending'
                  )";
@@ -333,20 +331,22 @@ class User
                 Project::associateUser($projects[$i], $new_usr_id, $role);
             }
             // send confirmation email to user
-            $hash = md5($HTTP_POST_VARS["full_name"] . md5($HTTP_POST_VARS["email"]) . $GLOBALS["private_key"]);
-            $msg = "Hello,\n\n";
-            $msg .= "We just received a request to create a new account in our issue tracking system. ";
-            $msg .= "For security reasons we need you to confirm this request so we can finish the account creation process.\n\n";
-            $msg .= "If this is not a real request from you, or you are not interested in creating a new account anymore, ";
-            $msg .= "please disregard this email. In a week the request will be erased automatically.\n\n";
-            $msg .= "However, if you would like to confirm the new account, please do so by visiting the URL below:\n\n";
-            $msg .= APP_BASE_URL . "confirm.php?cat=newuser&email=" . $HTTP_POST_VARS["email"] . "&hash=" . $hash . "\n\n";
+            $hash = md5($_POST["full_name"] . md5($_POST["email"]) . $GLOBALS["private_key"]);
+
+            $tpl = new Template_API;
+            $tpl->setTemplate('notifications/visitor_account.tpl.text');
+            $tpl->bulkAssign(array(
+                "app_title"   => Misc::getToolCaption(),
+                "email"     =>  $_POST['email'],
+                'hash'      =>  $hash
+            ));
+            $text_message = $tpl->getTemplateContents();
 
             $setup = Setup::load();
             $mail = new Mail_API;
             // need to make this message MIME based
-            $mail->setTextBody($msg);
-            $mail->send($setup["smtp"]["from"], $HTTP_POST_VARS["email"], APP_SHORT_NAME . ": New Account - Confirmation Required");
+            $mail->setTextBody($text_message);
+            $mail->send($setup["smtp"]["from"], $_POST["email"], APP_SHORT_NAME . ": New Account - Confirmation Required");
             return 1;
         }
     }
@@ -365,18 +365,20 @@ class User
         $info = User::getDetails($usr_id);
         // send confirmation email to user
         $hash = md5($info["usr_full_name"] . md5($info["usr_email"]) . $GLOBALS["private_key"]);
-        $msg = "Hello,\n\n";
-        $msg .= "We just received a request to create a new random password for your account in our issue tracking system. ";
-        $msg .= "For security reasons we need you to confirm this request so we can finish the password creation process.\n\n";
-        $msg .= "If this is not a real request from you, or if you don't need a new password anymore, ";
-        $msg .= "please disregard this email.\n\n";
-        $msg .= "However, if you would like to confirm this request, please do so by visiting the URL below:\n\n";
-        $msg .= APP_BASE_URL . "confirm.php?cat=password&email=" . $info["usr_email"] . "&hash=" . $hash . "\n\n";
+
+        $tpl = new Template_API;
+        $tpl->setTemplate('notifications/password_confirmation.tpl.text');
+        $tpl->bulkAssign(array(
+            "app_title" => Misc::getToolCaption(),
+            "user"      =>  $info,
+            'hash'      =>  $hash
+        ));
+        $text_message = $tpl->getTemplateContents();
 
         $setup = Setup::load();
         $mail = new Mail_API;
         // need to make this message MIME based
-        $mail->setTextBody($msg);
+        $mail->setTextBody($text_message);
         $mail->send($setup["smtp"]["from"], $info["usr_email"], APP_SHORT_NAME . ": New Password - Confirmation Required");
     }
 
@@ -391,12 +393,10 @@ class User
      */
     function confirmNewPassword($email)
     {
-        global $HTTP_POST_VARS;
-
         $usr_id = User::getUserIDByEmail($email);
         // create the new password
-        $HTTP_POST_VARS["new_password"] = substr(md5(microtime() . uniqid("")), 0, 12);
-        $HTTP_POST_VARS["confirm_password"] = $HTTP_POST_VARS["new_password"];
+        $_POST["new_password"] = substr(md5(microtime() . uniqid("")), 0, 12);
+        $_POST["confirm_password"] = $_POST["new_password"];
         User::updatePassword($usr_id, true);
     }
 
@@ -499,9 +499,9 @@ class User
         if ($prj_id != false) {
             $stmt .= " AND pru_prj_id = " . Misc::escapeInteger($prj_id) . " AND
                        usr_id = pru_usr_id";
-        }
-        if ($role != NULL) {
-            $stmt .= " AND pru_role > $role ";
+            if ($role != NULL) {
+                $stmt .= " AND pru_role > $role ";
+            }
         }
         if ($grp_id != false) {
             if ($exclude_grouped == false) {
@@ -555,19 +555,17 @@ class User
     function getRoles($exclude_role = FALSE)
     {
         if ($exclude_role == false) {
-            return $GLOBALS["roles"];
+            return $GLOBALS['localized_roles'];
         } else {
+            $roles = $GLOBALS['localized_roles'];
             if (!is_array($exclude_role)) {
                 $exclude_role = array($exclude_role);
             }
-            $exclude_role = array_map('strtolower', $exclude_role);
-            $t = array();
-            foreach ($GLOBALS["roles"] as $role_id => $role_title) {
-                if (!in_array(strtolower($role_title), $exclude_role)) {
-                    $t[$role_id] = $role_title;
-                }
+            foreach ($exclude_role as $role_title) {
+                unset($roles[User::getRoleID($role_title)]);
             }
-            return $t;
+
+            return $roles;
         }
     }
 
@@ -581,7 +579,7 @@ class User
      */
     function getRole($role_id)
     {
-        return $GLOBALS["roles"][$role_id];
+        return $GLOBALS['localized_roles'][$role_id];
     }
 
 
@@ -616,6 +614,10 @@ class User
     {
         static $returns;
 
+        if ($usr_id == APP_SYSTEM_USER_ID) {
+            return User::getRoleID("Administrator");
+        }
+
         if (!empty($returns[$usr_id][$prj_id])) {
             return $returns[$usr_id][$prj_id];
         }
@@ -715,6 +717,61 @@ class User
     }
 
 
+    /**
+     * Method used to get the email address of the specified user.
+     *
+     * @access  public
+     * @param   integer $usr_id The user ID or user ids
+     * @return  string The user' full name
+     */
+    function getEmail($usr_id)
+    {
+        static $returns;
+
+        if (!is_array($usr_id)) {
+            $items = array($usr_id);
+        } else {
+            $items = $usr_id;
+        }
+
+        $key = md5(serialize($usr_id));
+        if (!empty($returns[$key])) {
+            return $returns[$key];
+        }
+
+        if (count($items) < 1) {
+            if (!is_array($usr_id)) {
+                return '';
+            } else {
+                return array();
+            }
+        }
+
+        $stmt = "SELECT
+                    usr_email
+                 FROM
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
+                 WHERE
+                    usr_id IN (" . implode(', ', Misc::escapeInteger($items)) . ")";
+        if (!is_array($usr_id)) {
+            $res = $GLOBALS["db_api"]->dbh->getOne($stmt);
+        } else {
+            $res = $GLOBALS["db_api"]->dbh->getCol($stmt);
+        }
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            if (!is_array($usr_id)) {
+                return '';
+            } else {
+                return array();
+            }
+        } else {
+            $returns[$key] = $res;
+            return $res;
+        }
+    }
+
+
     /**
      * Method used to get the group id of the specified user.
      *
@@ -799,8 +856,6 @@ class User
      */
     function changeStatus()
     {
-        global $HTTP_POST_VARS;
-
         // check if the user being inactivated is the last one
         $stmt = "SELECT
                     COUNT(*)
@@ -809,15 +864,15 @@ class User
                  WHERE
                     usr_status='active'";
         $total_active = $GLOBALS["db_api"]->dbh->getOne($stmt);
-        if (($total_active < 2) && ($HTTP_POST_VARS["status"] == "inactive")) {
+        if (($total_active < 2) && ($_POST["status"] == "inactive")) {
             return false;
         }
 
-        $items = @implode(", ", Misc::escapeInteger($HTTP_POST_VARS["items"]));
+        $items = @implode(", ", Misc::escapeInteger($_POST["items"]));
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
-                    usr_status='" . $HTTP_POST_VARS["status"] . "'
+                    usr_status='" . $_POST["status"] . "'
                  WHERE
                     usr_id IN ($items)";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -840,15 +895,13 @@ class User
      */
     function updatePassword($usr_id, $send_notification = FALSE)
     {
-        global $HTTP_POST_VARS;
-
-        if ($HTTP_POST_VARS['new_password'] != $HTTP_POST_VARS['confirm_password']) {
+        if ($_POST['new_password'] != $_POST['confirm_password']) {
             return -2;
         }
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
-                    usr_password='" . Auth::hashPassword($HTTP_POST_VARS["new_password"]) . "'
+                    usr_password='" . Auth::hashPassword($_POST["new_password"]) . "'
                  WHERE
                     usr_id=" . Misc::escapeInteger($usr_id);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -857,7 +910,7 @@ class User
             return -1;
         } else {
             if ($send_notification) {
-                Notification::notifyUserPassword($usr_id, $HTTP_POST_VARS["new_password"]);
+                Notification::notifyUserPassword($usr_id, $_POST["new_password"]);
             }
             return 1;
         }
@@ -873,12 +926,10 @@ class User
      */
     function updateFullName($usr_id)
     {
-        global $HTTP_POST_VARS;
-
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
-                    usr_full_name='" . Misc::escapeString($HTTP_POST_VARS["full_name"]) . "'
+                    usr_full_name='" . Misc::escapeString($_POST["full_name"]) . "'
                  WHERE
                     usr_id=" . Misc::escapeInteger($usr_id);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -901,12 +952,10 @@ class User
      */
     function updateEmail($usr_id)
     {
-        global $HTTP_POST_VARS;
-
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
-                    usr_email='" . Misc::escapeString($HTTP_POST_VARS["email"]) . "'
+                    usr_email='" . Misc::escapeString($_POST["email"]) . "'
                  WHERE
                     usr_id=" . Misc::escapeInteger($usr_id);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -928,25 +977,23 @@ class User
      */
     function update()
     {
-        global $HTTP_POST_VARS;
-
         // system account should not be updateable
-        if ($HTTP_POST_VARS["id"] == APP_SYSTEM_USER_ID) {
+        if ($_POST["id"] == APP_SYSTEM_USER_ID) {
             return 1;
         }
 
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
-                    usr_full_name='" . Misc::escapeString($HTTP_POST_VARS["full_name"]) . "',
-                    usr_email='" . Misc::escapeString($HTTP_POST_VARS["email"]) . "'";
-        if (!empty($HTTP_POST_VARS["password"])) {
+                    usr_full_name='" . Misc::escapeString($_POST["full_name"]) . "',
+                    usr_email='" . Misc::escapeString($_POST["email"]) . "'";
+        if (!empty($_POST["password"])) {
             $stmt .= ",
-                    usr_password='" . Auth::hashPassword($HTTP_POST_VARS["password"]) . "'";
+                    usr_password='" . Auth::hashPassword($_POST["password"]) . "'";
         }
         $stmt .= "
                  WHERE
-                    usr_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                    usr_id=" . Misc::escapeInteger($_POST["id"]);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -956,13 +1003,13 @@ class User
             $stmt = "DELETE FROM
                         " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_user
                      WHERE
-                        pru_usr_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                        pru_usr_id=" . Misc::escapeInteger($_POST["id"]);
             $res = $GLOBALS["db_api"]->dbh->query($stmt);
             if (PEAR::isError($res)) {
                 Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
                 return -1;
             } else {
-                foreach ($HTTP_POST_VARS["role"] as $prj_id => $role) {
+                foreach ($_POST["role"] as $prj_id => $role) {
                     if ($role < 1) {
                         continue;
                     }
@@ -974,7 +1021,7 @@ class User
                                 pru_role
                              ) VALUES (
                                 " . $prj_id . ",
-                                " . Misc::escapeInteger($HTTP_POST_VARS["id"]) . ",
+                                " . Misc::escapeInteger($_POST["id"]) . ",
                                 " . $role . "
                              )";
                     $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -984,10 +1031,10 @@ class User
                     }
                 }
             }
-            if (!empty($HTTP_POST_VARS["password"])) {
-                Notification::notifyUserPassword($HTTP_POST_VARS["id"], $HTTP_POST_VARS["password"]);
+            if (!empty($_POST["password"])) {
+                Notification::notifyUserPassword($_POST["id"], $_POST["password"]);
             } else {
-                Notification::notifyUserAccount($HTTP_POST_VARS["id"]);
+                Notification::notifyUserAccount($_POST["id"]);
             }
             return 1;
         }
@@ -1002,10 +1049,8 @@ class User
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
         $projects = array();
-        foreach ($HTTP_POST_VARS["role"] as $prj_id => $role) {
+        foreach ($_POST["role"] as $prj_id => $role) {
             if ($role < 1) {
                 continue;
             }
@@ -1026,9 +1071,9 @@ class User
                     NULL,
                     NULL,
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . Auth::hashPassword(Misc::escapeString($HTTP_POST_VARS["password"])) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["full_name"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["email"]) . "',
+                    '" . Auth::hashPassword(Misc::escapeString($_POST["password"])) . "',
+                    '" . Misc::escapeString($_POST["full_name"]) . "',
+                    '" . Misc::escapeString($_POST["email"]) . "',
                     '" . Misc::escapeString($prefs) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -1038,14 +1083,14 @@ class User
         } else {
             $new_usr_id = $GLOBALS["db_api"]->get_last_insert_id();
             // add the project associations!
-            foreach ($HTTP_POST_VARS["role"] as $prj_id => $role) {
+            foreach ($_POST["role"] as $prj_id => $role) {
                 if ($role < 1) {
                     continue;
                 }
                 Project::associateUser($prj_id, $new_usr_id, $role);
             }
             // send email to user
-            Notification::notifyNewUser($new_usr_id, $HTTP_POST_VARS["password"]);
+            Notification::notifyNewUser($new_usr_id, $_POST["password"]);
             return 1;
         }
     }
@@ -1331,10 +1376,70 @@ class User
         }
         return 1;
     }
+
+
+    function getLang($usr_id, $force_refresh = false)
+    {
+        static $returns;
+
+        $usr_id = Misc::escapeInteger($usr_id);
+        if ((empty($returns[$usr_id])) || ($force_refresh == true)) {
+            $sql = "SELECT
+                        usr_lang
+                    FROM
+                        " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
+                    WHERE
+                        usr_id = $usr_id";
+            $res = $GLOBALS["db_api"]->dbh->getOne($sql);
+            if (PEAR::isError($res)) {
+                Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+                return APP_DEFAULT_LOCALE;
+            } else {
+                if (empty($res)) {
+                    $res = APP_DEFAULT_LOCALE;
+                }
+                $returns[$usr_id] = $res;
+            }
+        }
+        return $returns[$usr_id];
+    }
+
+
+    function setLang($usr_id, $language)
+    {
+        $sql = "UPDATE
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
+                SET
+                    usr_lang = '" . Misc::escapeString($language) . "'
+                WHERE
+                    usr_id = " . Misc::escapeInteger($usr_id);
+        $res = $GLOBALS["db_api"]->dbh->query($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return false;
+        }
+        return true;
+    }
+
+
+    function setLocalizedRoles()
+    {
+        $GLOBALS['localized_roles'] = array(
+            1 => ev_gettext("Viewer"),
+            2 => ev_gettext("Reporter"),
+            3 => ev_gettext("Customer"),
+            4 => ev_gettext("Standard User"),
+            5 => ev_gettext("Developer"),
+            6 => ev_gettext("Manager"),
+            7 => ev_gettext("Administrator")
+        );
+    }
+
 }
 
+User::setLocalizedRoles();
+
 // benchmarking the included file (aka setup time)
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included User Class');
 }
-?>
\ No newline at end of file
