@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -105,7 +105,7 @@ class Workflow
             $file_name_chunks = explode(".", $backend_class);
             $class_name = $file_name_chunks[1] . "_Workflow_Backend";
 
-            include_once(APP_INC_PATH . "workflow/$backend_class");
+            require_once(APP_INC_PATH . "workflow/$backend_class");
 
             $setup_backends[$prj_id] = new $class_name;
         }
@@ -139,7 +139,7 @@ class Workflow
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $usr_id The ID of the user.
      * @param   array $old_details The old details of the issues.
-     * @param   array $changes The changes that were applied to this issue (the $HTTP_POST_VARS)
+     * @param   array $changes The changes that were applied to this issue (the $_POST)
      */
     function handleIssueUpdated($prj_id, $issue_id, $usr_id, $old_details, $changes)
     {
@@ -192,7 +192,7 @@ class Workflow
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $usr_id The id of the user who locked the issue.
      * @param   array $old_details The old details of the issue.
-     * @param   array $changes The changes that were applied to this issue (the $HTTP_POST_VARS)
+     * @param   array $changes The changes that were applied to this issue (the $_POST)
      */
     function handlePriorityChange($prj_id, $issue_id, $usr_id, $old_details, $changes)
     {
@@ -302,14 +302,15 @@ class Workflow
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $usr_id The user ID of the person posting this new note
      * @param   boolean $closing If the issue is being closed
+     * @param   integer $note_id The ID of the new note
      */
-    function handleNewNote($prj_id, $issue_id, $usr_id, $closing = false)
+    function handleNewNote($prj_id, $issue_id, $usr_id, $closing = false, $note_id = false)
     {
         if (!Workflow::hasWorkflowIntegration($prj_id)) {
             return;
         }
         $backend =& Workflow::_getBackend($prj_id);
-        return $backend->handleNewNote($prj_id, $issue_id, $usr_id, $closing);
+        return $backend->handleNewNote($prj_id, $issue_id, $usr_id, $closing, $note_id);
     }
 
 
@@ -376,7 +377,7 @@ class Workflow
      * @param   integer $prj_id The project ID
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $subscriber_usr_id The ID of the user to subscribe if this is a real user (false otherwise).
-     * @param   string $email The email address to subscribe to subscribe (if this is not a real user).
+     * @param   string $email The email address  to subscribe (if this is not a real user).
      * @param   array $types The action types.
      * @return  mixed An array of information or true to continue unchanged or false to prevent the user from being added.
      */
@@ -482,7 +483,28 @@ class Workflow
         $backend =& Workflow::_getBackend($prj_id);
         return $backend->handleAuthorizedReplierAdded($prj_id, $issue_id, $email);
     }
+
+
+    /**
+     * Called at the begining of the email download process. If it returns true, the
+     * rest of the email code will not be executed.
+     *
+     * @param   integer $prj_id The project ID
+     * @param   array $info An array containing the information on the email account.
+     * @param   resource $mbox The imap connection resource
+     * @param   integer $num The sequential email number
+     * @param   string $message The complete email message
+     * @param   object $email An object containing the decoded email
+     * @return  mixed null by default, -1 if the rest of the email script should not be processed.
+     */
+    function preEmailDownload($prj_id, $info, $mbox, $num, &$message, &$email)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return null;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->preEmailDownload($prj_id, $info, $mbox, $num, $message, $email);
+    }
 }
 
 
-?>
\ No newline at end of file
