@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,27 +22,27 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.list.php 1.16 03/10/14 15:38:03-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.category.php");
-include_once(APP_INC_PATH . "class.priority.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.release.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.filter.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.group.php");
-include_once(APP_INC_PATH . "class.display_column.php");
-include_once(APP_INC_PATH . "class.search_profile.php");
+// @(#) $Id: list.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.category.php");
+require_once(APP_INC_PATH . "class.priority.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.release.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.filter.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.group.php");
+require_once(APP_INC_PATH . "class.display_column.php");
+require_once(APP_INC_PATH . "class.search_profile.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("list.tpl.html");
@@ -75,17 +75,17 @@ $tpl->assign("sorting", Issue::getSortingInfo($options));
 $groups = Group::getAssocList($prj_id);
 $users = Project::getUserAssocList($prj_id, 'active', User::getRoleID('Customer'));
 $assign_options = array(
-    ""      =>  "Any",
-    "-1"    =>  "un-assigned",
-    "-2"    =>  "myself and un-assigned"
+    ""      =>  ev_gettext("Any"),
+    "-1"    =>  ev_gettext("un-assigned"),
+    "-2"    =>  ev_gettext("myself and un-assigned")
 );
 if (User::getGroupID($usr_id) != '') {
-    $assign_options['-3'] = 'myself and my group';
-    $assign_options['-4'] = 'myself, un-assigned and my group';
+    $assign_options['-3'] = ev_gettext('myself and my group');
+    $assign_options['-4'] = ev_gettext('myself, un-assigned and my group');
 }
 if ((count($groups) > 0) && (Auth::getCurrentRole() > User::getRoleID("Customer"))) {
     foreach ($groups as $grp_id => $grp_name) {
-        $assign_options["grp:$grp_id"] = "Group: " . $grp_name;
+        $assign_options["grp:$grp_id"] = ev_gettext("Group") . ": " . $grp_name;
     }
 }
 $assign_options += $users;
@@ -130,4 +130,3 @@ $tpl->assign("refresh_rate", $prefs['list_refresh_rate'] * 60);
 $tpl->assign("refresh_page", "list.php");
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
