@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,53 +22,53 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.login.php 1.21 03/10/08 17:06:06-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.validation.php");
+// @(#) $Id: login.php 3307 2007-04-11 23:50:22Z balsdorf $
 
-if (Validation::isWhitespace($HTTP_POST_VARS["email"])) {
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.validation.php");
+
+if (Validation::isWhitespace($_POST["email"])) {
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=1");
 }
-if (Validation::isWhitespace($HTTP_POST_VARS["passwd"])) {
-    Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'failure', 'empty password');
-    Auth::redirect(APP_RELATIVE_URL . "index.php?err=2&email=" . $HTTP_POST_VARS["email"]);
+if (Validation::isWhitespace($_POST["passwd"])) {
+    Auth::saveLoginAttempt($_POST["email"], 'failure', 'empty password');
+    Auth::redirect(APP_RELATIVE_URL . "index.php?err=2&email=" . $_POST["email"]);
 }
 
 // check if user exists
-if (!Auth::userExists($HTTP_POST_VARS["email"])) {
-    Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'failure', 'unknown user');
+if (!Auth::userExists($_POST["email"])) {
+    Auth::saveLoginAttempt($_POST["email"], 'failure', 'unknown user');
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=3");
 }
 // check if the password matches
-if (!Auth::isCorrectPassword($HTTP_POST_VARS["email"], $HTTP_POST_VARS["passwd"])) {
-    Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'failure', 'wrong password');
-    Auth::redirect(APP_RELATIVE_URL . "index.php?err=3&email=" . $HTTP_POST_VARS["email"]);
+if (!Auth::isCorrectPassword($_POST["email"], $_POST["passwd"])) {
+    Auth::saveLoginAttempt($_POST["email"], 'failure', 'wrong password');
+    Auth::redirect(APP_RELATIVE_URL . "index.php?err=3&email=" . $_POST["email"]);
 }
 // check if this user did already confirm his account
-if (Auth::isPendingUser($HTTP_POST_VARS["email"])) {
-    Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'failure', 'pending user');
+if (Auth::isPendingUser($_POST["email"])) {
+    Auth::saveLoginAttempt($_POST["email"], 'failure', 'pending user');
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=9", $is_popup);
 }
 // check if this user is really an active one
-if (!Auth::isActiveUser($HTTP_POST_VARS["email"])) {
-    Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'failure', 'inactive user');
+if (!Auth::isActiveUser($_POST["email"])) {
+    Auth::saveLoginAttempt($_POST["email"], 'failure', 'inactive user');
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=7", $is_popup);
 }
 
-Auth::saveLoginAttempt($HTTP_POST_VARS["email"], 'success');
+Auth::saveLoginAttempt($_POST["email"], 'success');
 // redirect to the initial page
-@Auth::createLoginCookie(APP_COOKIE, $HTTP_POST_VARS["email"], $HTTP_POST_VARS["remember_login"]);
-if (!empty($HTTP_POST_VARS["url"])) {
-    $extra = '?url=' . urlencode($HTTP_POST_VARS["url"]);
+@Auth::createLoginCookie(APP_COOKIE, $_POST["email"]);
+Session::init(User::getUserIDByEmail($_POST['email']));
+if (!empty($_POST["url"])) {
+    $extra = '?url=' . urlencode($_POST["url"]);
 } else {
     $extra = '';
 }
 Auth::redirect(APP_RELATIVE_URL . "select_project.php" . $extra);
-?>
\ No newline at end of file
