@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,13 +22,13 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.logout.php 1.6 03/01/20 05:09:53-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.auth.php");
+// @(#) $Id: logout.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.auth.php");
 
 Auth::removeCookie(APP_COOKIE);
 
@@ -38,4 +38,3 @@ if (empty($project_cookie['remember'])) {
     Auth::removeCookie(APP_PROJECT_COOKIE);
 }
 Auth::redirect(APP_RELATIVE_URL . "index.php?err=6");
-?>
\ No newline at end of file
