@@ -1,6 +1,6 @@
 <?php
-include_once("../../config.inc.php");
-include_once(APP_INC_PATH . "class.misc.php");
+require_once(dirname(__FILE__) . "/../../init.php");
+require_once(APP_INC_PATH . "class.misc.php");
 
 $compile_dir = APP_PATH . "templates_c";
 $templates = Misc::getFileList($compile_dir);
