@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,24 +22,24 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.new.php 1.14 03/07/11 05:04:05-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.category.php");
-include_once(APP_INC_PATH . "class.priority.php");
-include_once(APP_INC_PATH . "class.release.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.group.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "class.custom_field.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: new.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.category.php");
+require_once(APP_INC_PATH . "class.priority.php");
+require_once(APP_INC_PATH . "class.release.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.group.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "class.custom_field.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("new.tpl.html");
@@ -55,7 +55,7 @@ if (Customer::hasCustomerIntegration($prj_id)) {
     if (Auth::getCurrentRole() == User::getRoleID('Customer')) {
         $customer_id = User::getCustomerID($usr_id);
         // check if the current customer has already redeemed all available per-incident tickets
-        if ((empty($HTTP_POST_VARS['cat'])) && (Customer::hasPerIncidentContract($prj_id, $customer_id)) &&
+        if ((empty($_POST['cat'])) && (Customer::hasPerIncidentContract($prj_id, $customer_id)) &&
                 (!Customer::hasIncidentsLeft($prj_id, $customer_id))) {
             // show warning about per-incident limitation
             $tpl->setTemplate("customer/" . Customer::getBackendImplementationName($prj_id) . "/incident_limit_reached.tpl.html");
@@ -67,7 +67,7 @@ if (Customer::hasCustomerIntegration($prj_id)) {
     }
 }
 
-if (@$HTTP_POST_VARS["cat"] == "report") {
+if (@$_POST["cat"] == "report") {
     $res = Issue::insert();
     if ($res != -1) {
         // show direct links to the issue page, issue listing page and
@@ -82,14 +82,14 @@ if (@$HTTP_POST_VARS["cat"] == "report") {
     }
 }
 
-if (@$HTTP_GET_VARS["cat"] == "associate") {
-    if (@count($HTTP_GET_VARS["item"]) > 0) {
-        $res = Support::getListDetails($HTTP_GET_VARS["item"]);
+if (@$_GET["cat"] == "associate") {
+    if (@count($_GET["item"]) > 0) {
+        $res = Support::getListDetails($_GET["item"]);
         $tpl->assign("emails", $res);
-        $tpl->assign("attached_emails", @implode(",", $HTTP_GET_VARS["item"]));
+        $tpl->assign("attached_emails", @implode(",", $_GET["item"]));
         if (Customer::hasCustomerIntegration($prj_id)) {
             // also need to guess the contact_id from any attached emails
-            $info = Customer::getCustomerInfoFromEmails($prj_id, $HTTP_GET_VARS["item"]);
+            $info = Customer::getCustomerInfoFromEmails($prj_id, $_GET["item"]);
             $tpl->assign(array(
                 "customer_id"   => $info['customer_id'],
                 'customer_name' => $info['customer_name'],
@@ -100,11 +100,11 @@ if (@$HTTP_GET_VARS["cat"] == "associate") {
         }
         // if we are dealing with just one message, use the subject line as the
         // summary for the issue, and the body as the description
-        if (count($HTTP_GET_VARS["item"]) == 1) {
-            $email_details = Support::getEmailDetails(Email_Account::getAccountByEmail($HTTP_GET_VARS["item"][0]), $HTTP_GET_VARS["item"][0]);
+        if (count($_GET["item"]) == 1) {
+            $email_details = Support::getEmailDetails(Email_Account::getAccountByEmail($_GET["item"][0]), $_GET["item"][0]);
             $tpl->assign(array(
                 'issue_summary'     => $email_details['sup_subject'],
-                'issue_description' => $email_details['message']
+                'issue_description' => $email_details['seb_body']
             ));
             // also auto pre-fill the customer contact text fields
             if (Customer::hasCustomerIntegration($prj_id)) {
@@ -147,4 +147,3 @@ if (User::getRole(Auth::getCurrentRole()) == "Customer") {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
