@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,18 +22,18 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.notification.php 1.10 03/08/20 17:49:55-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: notification.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("notification.tpl.html");
@@ -42,7 +42,7 @@ Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 
 $usr_id = Auth::getUserID();
 $prj_id = Auth::getCurrentProject();
-$issue_id = @$HTTP_POST_VARS["issue_id"] ? $HTTP_POST_VARS["issue_id"] : $HTTP_GET_VARS["iss_id"];
+$issue_id = @$_POST["issue_id"] ? $_POST["issue_id"] : $_GET["iss_id"];
 $tpl->assign("issue_id", $issue_id);
 
 // format default actions properly
@@ -53,17 +53,17 @@ foreach ($default as $action) {
 }
 $tpl->assign("default_actions", $res);
 
-if (@$HTTP_POST_VARS["cat"] == "insert") {
-    $res = Notification::subscribeEmail($usr_id, $issue_id, $HTTP_POST_VARS['email'], $HTTP_POST_VARS['actions']);
+if (@$_POST["cat"] == "insert") {
+    $res = Notification::subscribeEmail($usr_id, $issue_id, $_POST['email'], $_POST['actions']);
     $tpl->assign("insert_result", $res);
-} elseif (@$HTTP_GET_VARS["cat"] == "edit") {
-    $res = Notification::getDetails($HTTP_GET_VARS["id"]);
+} elseif (@$_GET["cat"] == "edit") {
+    $res = Notification::getDetails($_GET["id"]);
     $tpl->assign("info", $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "update") {
-    $res = Notification::update($HTTP_POST_VARS["id"]);
+} elseif (@$_POST["cat"] == "update") {
+    $res = Notification::update($_POST["id"]);
     $tpl->assign("update_result", $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "delete") {
-    $res = Notification::remove($HTTP_POST_VARS["items"]);
+} elseif (@$_POST["cat"] == "delete") {
+    $res = Notification::remove($_POST["items"]);
     $tpl->assign("delete_result", $res);
 }
 
@@ -73,4 +73,3 @@ $tpl->assign("assoc_users", $t);
 $tpl->assign("allowed_emails", Project::getAddressBookEmails($prj_id, $issue_id));
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
