@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,17 +22,17 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.note.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: post_note.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.note.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("post_note.tpl.html");
@@ -42,23 +42,23 @@ Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 $prj_id = Auth::getCurrentProject();
 $usr_id = Auth::getUserID();
 
-@$issue_id = $HTTP_GET_VARS["issue_id"] ? $HTTP_GET_VARS["issue_id"] : $HTTP_POST_VARS["issue_id"];
+@$issue_id = $_GET["issue_id"] ? $_GET["issue_id"] : $_POST["issue_id"];
 $details = Issue::getDetails($issue_id);
 $tpl->assign("issue_id", $issue_id);
 $tpl->assign("issue", $details);
 
-if (!Issue::canAccess($issue_id, $usr_id)) {
+if ((!Issue::canAccess($issue_id, $usr_id)) || (Auth::getCurrentRole() <= User::getRoleID("Customer"))) {
     $tpl->setTemplate("permission_denied.tpl.html");
     $tpl->displayTemplate();
     exit;
 }
 
-if (@$HTTP_POST_VARS["cat"] == "post_note") {
+if (@$_POST["cat"] == "post_note") {
     // change status
-    if (!@empty($HTTP_POST_VARS['new_status'])) {
-        $res = Issue::setStatus($issue_id, $HTTP_POST_VARS['new_status']);
+    if (!@empty($_POST['new_status'])) {
+        $res = Issue::setStatus($issue_id, $_POST['new_status']);
         if ($res != -1) {
-            $new_status = Status::getStatusTitle($HTTP_POST_VARS['new_status']);
+            $new_status = Status::getStatusTitle($_POST['new_status']);
             History::add($issue_id, $usr_id, History::getTypeID('status_changed'), "Status changed to '$new_status' by " . User::getFullName($usr_id));
         }
     }
@@ -66,21 +66,21 @@ if (@$HTTP_POST_VARS["cat"] == "post_note") {
     $res = Note::insert($usr_id, $issue_id);
     $tpl->assign("post_result", $res);
     // enter the time tracking entry about this phone support entry
-    if (!empty($HTTP_POST_VARS['time_spent'])) {
-        $HTTP_POST_VARS['issue_id'] = $issue_id;
-        $HTTP_POST_VARS['category'] = $HTTP_POST_VARS['time_category'];
-        $HTTP_POST_VARS['summary'] = 'Time entry inserted when sending an internal note.';
+    if (!empty($_POST['time_spent'])) {
+        $_POST['issue_id'] = $issue_id;
+        $_POST['category'] = $_POST['time_category'];
+        $_POST['summary'] = 'Time entry inserted when sending an internal note.';
         Time_Tracking::insertEntry();
     }
-} elseif (@$HTTP_GET_VARS["cat"] == "reply") {
-    if (!@empty($HTTP_GET_VARS["id"])) {
-        $note = Note::getDetails($HTTP_GET_VARS["id"]);
+} elseif (@$_GET["cat"] == "reply") {
+    if (!@empty($_GET["id"])) {
+        $note = Note::getDetails($_GET["id"]);
         $date = Misc::formatReplyDate($note["timestamp"]);
         $header = "\n\n\nOn $date, " . $note["not_from"] . " wrote:\n>\n";
         $note["not_body"] = $header . Misc::formatReply($note["not_note"]);
         $tpl->bulkAssign(array(
             "note"           => $note,
-            "parent_note_id" => $HTTP_GET_VARS["id"]
+            "parent_note_id" => $_GET["id"]
         ));
         $reply_subject = Mail_API::removeExcessRe($note['not_title']);
     }
@@ -103,4 +103,3 @@ $tpl->assign(array(
 ));
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
