@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                              |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,26 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.xmlrpc.php 1.10 03/11/17 16:04:48-00:00 jpradomaia $
+// @(#) $Id: xmlrpc.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
-include_once("../config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.note.php");
-include_once(APP_INC_PATH . "class.draft.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.authorized_replier.php");
-include_once(APP_INC_PATH . "class.report.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.customer.php");
+require_once(dirname(__FILE__) . "/../init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.note.php");
+require_once(APP_INC_PATH . "class.draft.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.authorized_replier.php");
+require_once(APP_INC_PATH . "class.report.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.customer.php");
 error_reporting(0);
-include_once(APP_PEAR_PATH . "XML_RPC/Server.php");
+require_once(APP_PEAR_PATH . "XML_RPC/Server.php");
 
 function authenticate($email, $password)
 {
@@ -653,7 +653,7 @@ function mayChangeIssue($p)
     }
 }
 
-$getWeeklyReport_sig = array(array($XML_RPC_String, $XML_RPC_String, $XML_RPC_String, $XML_RPC_Int, $XML_RPC_String, $XML_RPC_String));
+$getWeeklyReport_sig = array(array($XML_RPC_String, $XML_RPC_String, $XML_RPC_String, $XML_RPC_Int, $XML_RPC_String, $XML_RPC_String, $XML_RPC_Int));
 function getWeeklyReport($p)
 {
     $email = XML_RPC_decode($p->getParam(0));
@@ -665,6 +665,7 @@ function getWeeklyReport($p)
     $week = abs(XML_RPC_decode($p->getParam(2)));
     $start = XML_RPC_decode($p->getParam(3));
     $end = XML_RPC_decode($p->getParam(4));
+    $separate_closed = XML_RPC_decode($p->getParam(5));
     
     // we have to set a project so the template class works, even though the weekly report doesn't actually need it
     $projects = Project::getAssocList(Auth::getUserID());
@@ -680,9 +681,14 @@ function getWeeklyReport($p)
         $start = date("Y-m-d", $start);
     }
     
+    if ($separate_closed) {
+        // emulate smarty value for reports/weekly_data.tpl.tmpl:
+        // {if $smarty.post.separate_closed == 1}
+        $_POST['separate_closed'] = true;
+    }
     $tpl = new Template_API();
     $tpl->setTemplate("reports/weekly_data.tpl.html");
-    $tpl->assign("data", Report::getWeeklyReport(User::getUserIDByEmail($email), $start, $end));
+    $tpl->assign("data", Report::getWeeklyReport(User::getUserIDByEmail($email), $start, $end, $separate_closed));
     
     $ret = $tpl->getTemplateContents(). "\n";
     return new XML_RPC_Response(XML_RPC_Encode(base64_encode($ret)));
@@ -948,19 +954,17 @@ function logCommand($p)
  */
 function createFakeCookie($email, $project = false)
 {
-    global $HTTP_COOKIE_VARS;
-
     $cookie = array(
         "email" => $email
     );
-    $HTTP_COOKIE_VARS[APP_COOKIE] = base64_encode(serialize($cookie));
+    $_COOKIE[APP_COOKIE] = base64_encode(serialize($cookie));
     if ($project) {
         $cookie = array(
             "prj_id"   => $project,
             "remember" => false
         );
     }
-    $HTTP_COOKIE_VARS[APP_PROJECT_COOKIE] = base64_encode(serialize($cookie));
+    $_COOKIE[APP_PROJECT_COOKIE] = base64_encode(serialize($cookie));
 }
 
 
@@ -1103,4 +1107,3 @@ $services = array(
     )
 );
 $server = new XML_RPC_Server($services);
-?>
\ No newline at end of file
