@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                              |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,31 +22,86 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: Bryan Alsdorf <bryan@mysql.com>                             |
+// | Authors: Elan Ruusamäe <glen@delfi.ee>                               |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.index.php 1.24 04/01/26 20:37:04-06:00 joao@kickass. $
-//
 
 // XXX: try reading $_ENV['HOSTNAME'] and then ask the user if nothing could be found
 // XXX: dynamically check the email blob and skips the email if it is bigger than 16mb on PHP4 versions
 
-ini_set("memory_limit", "64M");
+ini_set('memory_limit', '64M');
 set_magic_quotes_runtime(0);
 
-if (isset($_GET)) {
-    $HTTP_POST_VARS = $_POST;
-    $HTTP_GET_VARS = $_GET;
-    $HTTP_SERVER_VARS = $_SERVER;
-    $HTTP_ENV_VARS = $_ENV;
-    $HTTP_POST_FILES = $_FILES;
-    // seems like PHP 4.1.0 didn't implement the $_SESSION auto-global...
-    if (isset($_SESSION)) {
-        $HTTP_SESSION_VARS = $_SESSION;
-    }
-    $HTTP_COOKIE_VARS = $_COOKIE;
+ini_set('display_errors', 1);
+error_reporting(E_ALL);
+set_time_limit(0);
+define('APP_CHARSET', 'UTF-8');
+define('APP_DEFAULT_LOCALE', 'en_US');
+define('APP_PATH', realpath(dirname(__FILE__) . '/..') . '/');
+define('APP_INC_PATH', APP_PATH . 'include/');
+define('APP_PEAR_PATH', APP_INC_PATH . 'pear/');
+define('APP_SMARTY_PATH', APP_INC_PATH . 'Smarty/');
+define('APP_CONFIG_PATH', APP_PATH . 'config/');
+define('APP_SETUP_FILE', APP_CONFIG_PATH . 'setup.php');
+define('APP_TPL_PATH', APP_PATH . 'templates/');
+define('APP_TPL_COMPILE_PATH', APP_PATH . 'templates_c');
+define('APP_LOG_PATH', APP_PATH . 'logs/');
+define('APP_ERROR_LOG', APP_LOG_PATH . 'errors.log');
+define('APP_LOCKS_PATH', APP_PATH . 'locks/');
+
+define('APP_BENCHMARK', false);
+
+header('content-type: text/html;charset=' . APP_CHARSET);
+
+set_include_path(get_include_path() . PATH_SEPARATOR . APP_PEAR_PATH);
+require_once('File/Util.php');
+
+$html = checkRequirements();
+if (!empty($html)) {
+    echo $html;
+    exit;
 }
 
+require_once(APP_SMARTY_PATH . 'Smarty.class.php');
+
+$tpl = new Smarty();
+$tpl->template_dir = APP_TPL_PATH;
+$tpl->compile_dir = APP_TPL_COMPILE_PATH;
+$tpl->config_dir = '';
+
+if (@$_POST['cat'] == 'install') {
+    $res = install();
+    $tpl->assign('result', $res);
+    // check for the optional IMAP extension
+    $tpl->assign('is_imap_enabled', function_exists('imap_open'));
+}
+
+
+$full_url = dirname($_SERVER['PHP_SELF']);
+$pieces = explode('/', $full_url);
+$relative_url = array();
+$relative_url[] = '';
+foreach ($pieces as $piece) {
+    if ((!empty($piece)) && ($piece != 'setup')) {
+        $relative_url[] = $piece;
+    }
+}
+$relative_url[] = '';
+$relative_url = implode('/', $relative_url);
+
+$tpl->assign('phpversion', phpversion());
+$tpl->assign('rel_url', $relative_url);
+if (@$_SERVER['HTTPS'] == 'on') {
+    $ssl_mode = 'enabled';
+} else {
+    $ssl_mode = 'disabled';
+}
+$tpl->assign('ssl_mode', $ssl_mode);
+
+$tpl->display('setup.tpl.html');
+
+
 function checkPermissions($file, $desc, $is_directory = FALSE)
 {
     clearstatcache();
@@ -55,29 +110,29 @@ function checkPermissions($file, $desc, $is_directory = FALSE)
             // try to create the file ourselves then
             $fp = @fopen($file, 'w');
             if (!$fp) {
-                return "File '" . File_Util::realpath($file) . "' does not exist. Please create it (as a blank file) and try again.";
+                return  getPermissionError($file, $desc, $is_directory, false);
             }
             @fclose($fp);
         } else {
             if (!@mkdir($file)) {
-                return "$desc does not exist. Please create it and try again.";
+                return  getPermissionError($file, $desc, $is_directory, false);
             }
         }
     }
     clearstatcache();
     if (!is_writable($file)) {
-        if (!stristr(PHP_OS, "win")) {
+        if (!stristr(PHP_OS, 'win')) {
             // let's try to change the permissions ourselves
-            @chmod($file, 0777);
+            @chmod($file, 0644);
             clearstatcache();
             if (!is_writable($file)) {
-                return "$desc is not writable";
+                return getPermissionError($file, $desc, $is_directory, true);
             }
         } else {
-            return "$desc is not writable";
+            return getPermissionError($file, $desc, $is_directory, true);
         }
     }
-    if (stristr(PHP_OS, "win")) {
+    if (stristr(PHP_OS, 'win')) {
         // need to check whether we can really create files in this directory or not
         // since is_writable() is not trustworthy on windows platforms
         if (is_dir($file)) {
@@ -91,7 +146,26 @@ function checkPermissions($file, $desc, $is_directory = FALSE)
             @unlink($file . '/dummy.txt');
         }
     }
-    return "";
+    return '';
+}
+
+function getPermissionError($file, $desc, $is_directory, $exists)
+{
+    $error = '';
+    if ($is_directory) {
+        $title = 'Directory';
+    } else {
+        $title = 'File';
+    }
+    $error = "$title <b>'" . File_Util::realPath($file) . ($is_directory ? '/' : '') . "'</b> ";
+
+    if (!$exists) {
+        $error .= "does not exist. Please create the $title and reload this page.";
+    } else {
+        $error .= "is not writeable. Please change this $title to be writeable by the web server.";
+    }
+
+    return $error;
 }
 
 function checkRequirements()
@@ -103,49 +177,38 @@ function checkRequirements()
     phpinfo();
     $contents = ob_get_contents();
     ob_end_clean();
-    if (!preg_match("/GD Support.*<\/td><td.*>enabled/U", $contents)) {
-        $errors[] = "The GD extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.";
+    if (!preg_match('/GD Support.*<\/td><td.*>enabled/U', $contents)) {
+        $errors[] = 'The GD extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.';
     }
     // check for session support
     if (!function_exists('session_start')) {
-        $errors[] = "The Session extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.";
+        $errors[] = 'The Session extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.';
     }
     // check for MySQL support
     if (!function_exists('mysql_query')) {
-        $errors[] = "The MySQL extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.";
+        $errors[] = 'The MySQL extension needs to be enabled in your PHP.INI file in order for Eventum to work properly.';
     }
     // check for the file_uploads php.ini directive
     if (ini_get('file_uploads') != "1") {
         $errors[] = "The 'file_uploads' directive needs to be enabled in your PHP.INI file in order for Eventum to work properly.";
     }
-    if (ini_get('allow_call_time_pass_reference') != "1") {
-        $errors[] = "The 'allow_call_time_pass_reference' directive needs to be enabled in your PHP.INI file in order for Eventum to work properly.";
-    }
-    $error = checkPermissions('../locks', "Directory 'locks'", TRUE);
+    $error = checkPermissions(APP_CONFIG_PATH, "Directory '" . APP_CONFIG_PATH . "'", TRUE);
     if (!empty($error)) {
         $errors[] = $error;
     }
-    $error = checkPermissions('../logs', "Directory 'logs'", TRUE);
+    $error = checkPermissions(APP_LOCKS_PATH, "Directory '" . APP_LOCKS_PATH . "'", TRUE);
     if (!empty($error)) {
         $errors[] = $error;
     }
-    $error = checkPermissions('../templates_c', "Directory 'templates_c'", TRUE);
+    $error = checkPermissions(APP_LOG_PATH, "Directory '". APP_LOG_PATH . "'", TRUE);
     if (!empty($error)) {
         $errors[] = $error;
     }
-    $error = checkPermissions('../config.inc.php', "File 'config.inc.php'");
+    $error = checkPermissions(APP_TPL_COMPILE_PATH, "Directory '" . APP_TPL_COMPILE_PATH . "'", TRUE);
     if (!empty($error)) {
         $errors[] = $error;
     }
-    $error = checkPermissions('../logs/errors.log', "File 'logs/errors.log'");
-    if (!empty($error)) {
-        $errors[] = $error;
-    }
-    $error = checkPermissions('../setup.conf.php', "File 'setup.conf.php'");
-    if (!empty($error)) {
-        $errors[] = $error;
-    }
-    $error = checkPermissions('../include/private_key.php', "File 'include/private_key.php'");
+    $error = checkPermissions(APP_ERROR_LOG, "File '" . APP_ERROR_LOG . "'");
     if (!empty($error)) {
         $errors[] = $error;
     }
@@ -164,12 +227,13 @@ function checkRequirements()
 }
 -->
 </style>
+<title>Eventum Setup</title>
 </head>
 <body>
 
 <br /><br />
 
-<table width="500" bgcolor="#003366" border="0" cellspacing="0" cellpadding="1" align="center">
+<table width="600" bgcolor="#003366" border="0" cellspacing="0" cellpadding="1" align="center">
   <tr>
     <td>
       <table bgcolor="#FFFFFF" width="100%" cellspacing="1" cellpadding="2" border="0">
@@ -182,7 +246,7 @@ function checkRequirements()
             <br />
             <b>The following problems regarding file and/or directory permissions were found:</b>
             <br /><br />
-            ' . implode("<br />", $errors) . '
+            ' . implode("\n<hr>\n", $errors) . '
             <br /><br />
             <b>Please provide the appropriate permissions to the user that the web server run as to write in the directories and files specified above.</b>
             <br /><br />
@@ -199,33 +263,10 @@ function checkRequirements()
     return $html;
 }
 
-if (stristr(PHP_OS, 'darwin')) {
-    ini_set("include_path", ".:./../include/pear/");
-} elseif (stristr(PHP_OS, 'win')) {
-    ini_set("include_path", ".;./../include/pear/");
-} else {
-    ini_set("include_path", ".:./../include/pear/");
-}
-include_once("File/Util.php");
-
-$html = checkRequirements();
-if (!empty($html)) {
-    echo $html;
-    exit;
-}
-
-include_once("../include/Smarty/Smarty.class.php");
-
-$tpl = new Smarty();
-$tpl->template_dir = '../templates/en';
-$tpl->compile_dir = "../templates_c";
-$tpl->config_dir = '';
 
 function replace_table_prefix($str)
 {
-    global $HTTP_POST_VARS;
-
-    return str_replace('%TABLE_PREFIX%', $HTTP_POST_VARS['db_table_prefix'], $str);
+    return str_replace('%TABLE_PREFIX%', $_POST['db_table_prefix'], $str);
 }
 
 function getErrorMessage($type, $message)
@@ -283,72 +324,67 @@ function getTableList($conn)
 
 function install()
 {
-    global $HTTP_POST_VARS;
+    $private_key_path = APP_CONFIG_PATH . 'private_key.php';
+    $config_file_path = APP_CONFIG_PATH . 'config.php';
+    $setup_file_path = APP_SETUP_FILE;
 
     clearstatcache();
-    // check if config.inc.php in the root directory is writable
-    if (!is_writable('../config.inc.php')) {
-        return "The file 'config.inc.php' in Eventum's root directory needs to be writable by the web server user. Please correct this problem and try again.";
-    }
-    // gotta check and see if the provided installation path really exists...
-    if (!file_exists($HTTP_POST_VARS['path'])) {
-        return "The provided installation path could not be found. Please review your information and try again.";
+    // check if config directory is writable
+    if (!is_writable(APP_CONFIG_PATH)) {
+        return "The file '" . APP_CONFIG_PATH . "' directory needs to be writable by the web server user. Please correct this problem and try again.";
     }
     // need to create a random private key variable
     $private_key = '<?php
 $private_key = "' . md5(microtime()) . '";
 ?>';
-    if (!is_writable('../include/private_key.php')) {
-        return "The file 'include/private_key.php' needs to be writable by the web server user. Please correct this problem and try again.";
-    }
-    $fp = @fopen('../include/private_key.php', 'w');
+    $fp = @fopen($private_key_path, 'w');
     if ($fp === FALSE) {
-        return "Could not open the file 'include/private_key.php' for writing. The permissions on the file should be set as to allow the user that the web server runs as to open it. Please correct this problem and try again.";
+        return "Could not open the file '$private_key_path' for writing. The permissions on the file should be set as to allow the user that the web server runs as to open it. Please correct this problem and try again.";
     }
     $res = fwrite($fp, $private_key);
     if ($fp === FALSE) {
-        return "Could not write the configuration information to 'include/private_key.php'. The file should be writable by the user that the web server runs as. Please correct this problem and try again.";
+        return "Could not write the configuration information to '$private_key_path'. The file should be writable by the user that the web server runs as. Please correct this problem and try again.";
     }
     fclose($fp);
     // check if we can connect
-    $conn = @mysql_connect($HTTP_POST_VARS['db_hostname'], $HTTP_POST_VARS['db_username'], $HTTP_POST_VARS['db_password']);
+    $conn = @mysql_connect($_POST['db_hostname'], $_POST['db_username'], $_POST['db_password']);
     if (!$conn) {
         return getErrorMessage('connect', mysql_error());
     }
     $db_list = getDatabaseList($conn);
     $db_list = array_map('strtolower', $db_list);
-    if (@$HTTP_POST_VARS['create_db'] == 'yes') {
-        if (!in_array(strtolower($HTTP_POST_VARS['db_name']), $db_list)) {
-            if (!mysql_query('CREATE DATABASE ' . $HTTP_POST_VARS['db_name'], $conn)) {
+    if (@$_POST['create_db'] == 'yes') {
+        if (!in_array(strtolower($_POST['db_name']), $db_list)) {
+            if (!mysql_query('CREATE DATABASE ' . $_POST['db_name'], $conn)) {
                 return getErrorMessage('create_db', mysql_error());
             }
         }
     } else {
-        if ((count($db_list) > 0) && (!in_array(strtolower($HTTP_POST_VARS['db_name']), $db_list))) {
+        if ((count($db_list) > 0) && (!in_array(strtolower($_POST['db_name']), $db_list))) {
             return "The provided database name could not be found. Review your information or specify that the database should be created in the form below.";
         }
     }
     // create the new user, if needed
-    if (@$HTTP_POST_VARS["alternate_user"] == 'yes') {
+    if (@$_POST["alternate_user"] == 'yes') {
         $user_list = getUserList($conn);
         if (count($user_list) > 0) {
             $user_list = array_map('strtolower', $user_list);
-            if (@$HTTP_POST_VARS["create_user"] == 'yes') {
-                if (!in_array(strtolower(@$HTTP_POST_VARS['eventum_user']), $user_list)) {
-                    $stmt = "GRANT SELECT, UPDATE, DELETE, INSERT, ALTER, DROP, CREATE, INDEX ON " . $HTTP_POST_VARS['db_name'] . ".* TO '" . $HTTP_POST_VARS["eventum_user"] . "'@'%' IDENTIFIED BY '" . $HTTP_POST_VARS["eventum_password"] . "'";
+            if (@$_POST["create_user"] == 'yes') {
+                if (!in_array(strtolower(@$_POST['eventum_user']), $user_list)) {
+                    $stmt = "GRANT SELECT, UPDATE, DELETE, INSERT, ALTER, DROP, CREATE, INDEX ON " . $_POST['db_name'] . ".* TO '" . $_POST["eventum_user"] . "'@'%' IDENTIFIED BY '" . $_POST["eventum_password"] . "'";
                     if (!mysql_query($stmt, $conn)) {
                         return getErrorMessage('create_user', mysql_error());
                     }
                 }
             } else {
-                if (!in_array(strtolower(@$HTTP_POST_VARS['eventum_user']), $user_list)) {
+                if (!in_array(strtolower(@$_POST['eventum_user']), $user_list)) {
                     return "The provided MySQL username could not be found. Review your information or specify that the username should be created in the form below.";
                 }
             }
         }
     }
     // check if we can use the database
-    if (!mysql_select_db($HTTP_POST_VARS['db_name'])) {
+    if (!mysql_select_db($_POST['db_name'])) {
         return getErrorMessage('select_db', mysql_error());
     }
     // check the CREATE and DROP privileges by trying to create and drop a test table
@@ -369,7 +405,7 @@ $private_key = "' . md5(microtime()) . '";
     $queries = array_map("trim", $queries);
     $queries = array_map("replace_table_prefix", $queries);
     foreach ($queries as $stmt) {
-        if ((stristr($stmt, 'DROP TABLE')) && (@$HTTP_POST_VARS['drop_tables'] != 'yes')) {
+        if ((stristr($stmt, 'DROP TABLE')) && (@$_POST['drop_tables'] != 'yes')) {
             continue;
         }
         // need to check if a CREATE TABLE on an existing table throws an error
@@ -382,26 +418,21 @@ $private_key = "' . md5(microtime()) . '";
             return getErrorMessage($type, mysql_error());
         }
     }
-    // substitute the appropriate values in config.inc.php!!!
-    if (@$HTTP_POST_VARS['alternate_user'] == 'yes') {
-        $HTTP_POST_VARS['db_username'] = $HTTP_POST_VARS['eventum_user'];
-        $HTTP_POST_VARS['db_password'] = $HTTP_POST_VARS['eventum_password'];
+    // substitute the appropriate values in config.php!!!
+    if (@$_POST['alternate_user'] == 'yes') {
+        $_POST['db_username'] = $_POST['eventum_user'];
+        $_POST['db_password'] = $_POST['eventum_password'];
     }
-    // make sure there is a / in the end of the APP_PATH constant
-    if (substr($HTTP_POST_VARS['path'], 0, -1) != '/') {
-        $HTTP_POST_VARS['path'] .= '/';
-    }
-    $config_contents = implode("", file("config.inc.php"));
-    $config_contents = str_replace("%{APP_PATH}%", $HTTP_POST_VARS['path'], $config_contents);
-    $config_contents = str_replace("%{APP_SQL_DBHOST}%", $HTTP_POST_VARS['db_hostname'], $config_contents);
-    $config_contents = str_replace("%{APP_SQL_DBNAME}%", $HTTP_POST_VARS['db_name'], $config_contents);
-    $config_contents = str_replace("%{APP_SQL_DBUSER}%", $HTTP_POST_VARS['db_username'], $config_contents);
-    $config_contents = str_replace("%{APP_SQL_DBPASS}%", $HTTP_POST_VARS['db_password'], $config_contents);
-    $config_contents = str_replace("%{APP_TABLE_PREFIX}%", $HTTP_POST_VARS['db_table_prefix'], $config_contents);
-    $config_contents = str_replace("%{APP_HOSTNAME}%", $HTTP_POST_VARS['hostname'], $config_contents);
-    $config_contents = str_replace("%{APP_RELATIVE_URL}%", $HTTP_POST_VARS['relative_url'], $config_contents);
-    $config_contents = str_replace("%{APP_VERSION}%", "1.7.0", $config_contents);
-    if (@$HTTP_POST_VARS['is_ssl'] == 'yes') {
+    $config_contents = file_get_contents('config.php');
+    $config_contents = str_replace("%{APP_SQL_DBHOST}%", $_POST['db_hostname'], $config_contents);
+    $config_contents = str_replace("%{APP_SQL_DBNAME}%", $_POST['db_name'], $config_contents);
+    $config_contents = str_replace("%{APP_SQL_DBUSER}%", $_POST['db_username'], $config_contents);
+    $config_contents = str_replace("%{APP_SQL_DBPASS}%", $_POST['db_password'], $config_contents);
+    $config_contents = str_replace("%{APP_TABLE_PREFIX}%", $_POST['db_table_prefix'], $config_contents);
+    $config_contents = str_replace("%{APP_HOSTNAME}%", $_POST['hostname'], $config_contents);
+    $config_contents = str_replace("%{CHARSET}%", APP_CHARSET, $config_contents);
+    $config_contents = str_replace("%{APP_RELATIVE_URL}%", $_POST['relative_url'], $config_contents);
+    if (@$_POST['is_ssl'] == 'yes') {
         $protocol_type = 'https://';
     } else {
         $protocol_type = 'http://';
@@ -418,62 +449,31 @@ $private_key = "' . md5(microtime()) . '";
         $config_contents = str_replace("'%{APP_ENABLE_FULLTEXT}%'", "false", $config_contents);
     }
 
-    $fp = @fopen('../config.inc.php', 'w');
+    $fp = @fopen($config_file_path, 'w');
     if ($fp === FALSE) {
-        return "Could not open the file 'config.inc.php' for writing. The permissions on the file should be set as to allow the user that the web server runs as to open it. Please correct this problem and try again.";
+        return "Could not open the file '$config_file_path' for writing. The permissions on the file should be set as to allow the user that the web server runs as to open it. Please correct this problem and try again.";
     }
     $res = fwrite($fp, $config_contents);
     if ($fp === FALSE) {
-        return "Could not write the configuration information to 'config.inc.php'. The file should be writable by the user that the web server runs as. Please correct this problem and try again.";
+        return "Could not write the configuration information to '$config_file_path'. The file should be writable by the user that the web server runs as. Please correct this problem and try again.";
     }
     fclose($fp);
 
     // write setup file
-    include_once("../config.inc.php");
-    include_once(APP_INC_PATH . "class.setup.php");
+    require_once(APP_INC_PATH . "class.setup.php");
     $_REQUEST['setup']['update'] = 1;
     $_REQUEST['setup']['closed'] = 1;
     $_REQUEST['setup']['emails'] = 1;
     $_REQUEST['setup']['files'] = 1;
+    $_REQUEST['setup']['allow_unassigned_issues'] = 'yes';
+    $_REQUEST['setup']['support_email'] = 'enabled';
     Setup::save($_REQUEST['setup']);
 
     return 'success';
 }
 
-if (@$HTTP_POST_VARS["cat"] == 'install') {
-    $res = install();
-    $tpl->assign("result", $res);
-    // check for the optional IMAP extension
-    $tpl->assign('is_imap_enabled', function_exists('imap_open'));
+
+function ev_gettext($str)
+{
+    return $str;
 }
-
-
-$full_url = dirname($HTTP_SERVER_VARS['PHP_SELF']);
-$pieces = explode("/", $full_url);
-$relative_url = array();
-$relative_url[] = '';
-foreach ($pieces as $piece) {
-    if ((!empty($piece)) && ($piece != 'setup')) {
-        $relative_url[] = $piece;
-    }
-}
-$relative_url[] = '';
-$relative_url = implode("/", $relative_url);
-
-if (substr($HTTP_SERVER_VARS['DOCUMENT_ROOT'], -1) == '/') {
-    $HTTP_SERVER_VARS['DOCUMENT_ROOT'] = substr($HTTP_SERVER_VARS['DOCUMENT_ROOT'], 0, -1);
-}
-$installation_path = $HTTP_SERVER_VARS['DOCUMENT_ROOT'] . $relative_url;
-
-$tpl->assign("phpversion", phpversion());
-$tpl->assign("rel_url", $relative_url);
-$tpl->assign("installation_path", $installation_path);
-if (@$HTTP_SERVER_VARS['HTTPS'] == 'on') {
-    $ssl_mode = 'enabled';
-} else {
-    $ssl_mode = 'disabled';
-}
-$tpl->assign('ssl_mode', $ssl_mode);
-
-$tpl->display('setup.tpl.html');
-?>
