@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,21 +22,21 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.stats_chart.php 1.11 03/10/01 17:20:27-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.stats.php");
+// @(#) $Id: stats_chart.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.stats.php");
 
 ini_set('memory_limit', '64M');
 error_reporting(0);
 
-@include_once(APP_JPGRAPH_PATH . "jpgraph.php");
-@include_once(APP_JPGRAPH_PATH . "jpgraph_pie.php");
+@require_once(APP_JPGRAPH_PATH . "jpgraph.php");
+@require_once(APP_JPGRAPH_PATH . "jpgraph_pie.php");
 
 Auth::checkAuthentication(APP_COOKIE);
 
@@ -49,23 +49,29 @@ if (!@file_exists($ttf_font)) {
 }
 
 // Some data
-if ($HTTP_GET_VARS["plot"] == "status") {
+$colors = array();
+if ($_GET["plot"] == "status") {
     $data = Stats::getAssocStatus();
-    $graph_title = "Issues by Status";
-} elseif ($HTTP_GET_VARS["plot"] == "release") {
+    $graph_title = ev_gettext("Issues by Status");
+    foreach ($data as $sta_title => $trash) {
+        $sta_id = Status::getStatusID($sta_title);
+        $status_details = Status::getDetails($sta_id);
+        $colors[] = $status_details['sta_color'];
+    }
+} elseif ($_GET["plot"] == "release") {
     $data = Stats::getAssocRelease();
-    $graph_title = "Issues by Release";
-} elseif ($HTTP_GET_VARS["plot"] == "priority") {
+    $graph_title = ev_gettext("Issues by Release");
+} elseif ($_GET["plot"] == "priority") {
     $data = Stats::getAssocPriority();
-    $graph_title = "Issues by Priority";
-} elseif ($HTTP_GET_VARS["plot"] == "user") {
+    $graph_title = ev_gettext("Issues by Priority");
+} elseif ($_GET["plot"] == "user") {
     $data = Stats::getAssocUser();
-    $graph_title = "Issues by Assignment";
-} elseif ($HTTP_GET_VARS["plot"] == "category") {
+    $graph_title = ev_gettext("Issues by Assignment");
+} elseif ($_GET["plot"] == "category") {
     $data = Stats::getAssocCategory();
-    $graph_title = "Issues by Category";
+    $graph_title = ev_gettext("Issues by Category");
 }
-$labels = array_keys($data);
+$labels = array_map('utf8_decode', array_keys($data));
 $data = array_values($data);
 
 // check the values coming from the database and if they are all empty, then
@@ -84,7 +90,11 @@ $graph->title->SetFont($font, FS_BOLD, 12);
 
 // The pie plot
 $p1 = new PiePlot($data);
-$p1->SetTheme('pastel');
+if (count($colors) > 0) {
+    $p1->SetSliceColors($colors);
+} else {
+    $p1->SetTheme('pastel');
+}
 
 // Move center of pie to the left to make better room
 // for the legend
@@ -110,4 +120,3 @@ $graph->legend->Pos(0.06,0.27);
 
 $graph->Add($p1);
 $graph->Stroke();
-?>
\ No newline at end of file
