@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,28 +22,24 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.view_email.php 1.8 03/11/12 19:57:26-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: view_email.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("view_email.tpl.html");
 
 Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
-
-$email = Support::getEmailDetails($HTTP_GET_VARS["ema_id"], $HTTP_GET_VARS["id"]);
-$email["message"] = str_replace("&amp;nbsp;", "&nbsp;",$email["message"]);
-
-$issue_id = Support::getIssueFromEmail($HTTP_GET_VARS["id"]);
+$issue_id = Support::getIssueFromEmail($_GET["id"]);
 
 if (!Issue::canAccess($issue_id, Auth::getUserID())) {
     $tpl->setTemplate("permission_denied.tpl.html");
@@ -51,25 +47,27 @@ if (!Issue::canAccess($issue_id, Auth::getUserID())) {
     exit;
 }
 
+$email = Support::getEmailDetails($_GET["ema_id"], $_GET["id"]);
+$email['seb_body'] = str_replace("&amp;nbsp;", "&nbsp;", $email['seb_body']);
 $tpl->bulkAssign(array(
     "email"           => $email,
     "issue_id"        => $issue_id,
-    'extra_title'     => "Email #" . $HTTP_GET_VARS['id'] . ": " . $email['sup_subject'],
+    'extra_title'     => "Email #" . $_GET['id'] . ": " . $email['sup_subject'],
     'email_accounts'  =>  Email_Account::getAssocList(array_keys(Project::getAssocList(Auth::getUserID())), true)
 ));
 
-if (@$HTTP_GET_VARS['cat'] == 'list_emails') {
-    $sides = Support::getListingSides($HTTP_GET_VARS["id"]);
+if (@$_GET['cat'] == 'list_emails') {
+    $sides = Support::getListingSides($_GET["id"]);
     $tpl->assign(array(
         'previous' => $sides['previous'],
         'next'     => $sides['next']
     ));
-} elseif ((@$HTTP_GET_VARS['cat'] == 'move_email') && (Auth::getCurrentRole() >= User::getRoleID("Standard User"))) {
-    $res = Support::moveEmail(@$HTTP_GET_VARS['id'], @$HTTP_GET_VARS['ema_id'], @$HTTP_GET_VARS['new_ema_id']);
+} elseif ((@$_GET['cat'] == 'move_email') && (Auth::getCurrentRole() >= User::getRoleID("Standard User"))) {
+    $res = Support::moveEmail(@$_GET['id'], @$_GET['ema_id'], @$_GET['new_ema_id']);
     $tpl->assign("move_email_result", $res);
     $tpl->assign("current_user_prefs", Prefs::get(Auth::getUserID()));
 } else {
-    $sides = Support::getIssueSides($issue_id, $HTTP_GET_VARS["id"]);
+    $sides = Support::getIssueSides($issue_id, $_GET["id"]);
     $tpl->assign(array(
         'previous' => $sides['previous'],
         'next'     => $sides['next']
@@ -83,4 +81,3 @@ if (!empty($charset)) {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
