@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,19 +22,19 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.note.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: view_note.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.note.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("view_note.tpl.html");
@@ -42,7 +42,8 @@ $tpl->setTemplate("view_note.tpl.html");
 Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 $usr_id = Auth::getUserID();
 
-$note = Note::getDetails($HTTP_GET_VARS["id"]);
+$note_id = $_GET["id"];
+$note = Note::getDetails($note_id);
 
 if ($note == '') {
     $tpl->assign("note", '');
@@ -50,7 +51,7 @@ if ($note == '') {
     exit;
 } else {
     $note["message"] = $note["not_note"];
-    $issue_id = Note::getIssueID($HTTP_GET_VARS["id"]);
+    $issue_id = Note::getIssueID($note_id);
     $usr_id = Auth::getUserID();
 }
 
@@ -60,18 +61,18 @@ if ((User::getRoleByUser($usr_id, Issue::getProjectID($issue_id)) < User::getRol
     exit;
 }
 
-$note = Note::getDetails($HTTP_GET_VARS["id"]);
+$note = Note::getDetails($_GET["id"]);
 $note["message"] = $note["not_note"];
 
-$issue_id = Note::getIssueID($HTTP_GET_VARS["id"]);
+$issue_id = Note::getIssueID($_GET["id"]);
 $tpl->bulkAssign(array(
     "note"        => $note,
     "issue_id"    => $issue_id,
-    'extra_title' => "Note #" . $HTTP_GET_VARS['num'] . ": " . $note['not_title']
+    'extra_title' => "Note #" . Note::getNoteSequenceNumber($issue_id, $note_id) . ": " . $note['not_title'],
 ));
 
 if (!empty($issue_id)) {
-    $sides = Note::getSideLinks($issue_id, $HTTP_GET_VARS["id"]);
+    $sides = Note::getSideLinks($issue_id, $_GET["id"]);
     $tpl->assign(array(
         'previous' => $sides['previous'],
         'next'     => $sides['next']
@@ -79,4 +80,3 @@ if (!empty($issue_id)) {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
